@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2014-2017, Intel Corporation
+* Copyright (c) 2014-2019, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -353,7 +353,17 @@ MOS_STATUS CodechalSfcState::SetSfcStateParams(
     sfcStateParams->fAlphaPixel                    = 1.0F;
     sfcStateParams->bColorFillEnable               = m_colorFill;
     sfcStateParams->bCSCEnable                     = m_csc;
-    sfcStateParams->bRGBASwapEnable                = sfcStateParams->bCSCEnable;
+    // ARGB8,ABGR10 output format need to enable swap
+    if (m_sfcOutputSurface->Format == Format_X8R8G8B8 ||
+        m_sfcOutputSurface->Format == Format_A8R8G8B8 ||
+        m_sfcOutputSurface->Format == Format_R10G10B10A2)
+    {
+        sfcStateParams->bRGBASwapEnable = true;
+    }
+    else
+    {
+        sfcStateParams->bRGBASwapEnable = false;
+    }
 
     // CodecHal does not support SFC rotation
     sfcStateParams->RotationMode                   = MHW_ROTATION_IDENTITY;
@@ -747,7 +757,6 @@ bool CodechalSfcState::IsSfcOutputSupported(
         if (!MOS_WITHIN_RANGE(srcSurface->dwWidth, m_sfcInterface->m_minWidth, m_sfcInterface->m_maxWidth) ||
             !MOS_WITHIN_RANGE(srcSurface->dwHeight, m_sfcInterface->m_minHeight, m_sfcInterface->m_maxHeight))
         {
-            CODECHAL_DECODE_ASSERTMESSAGE("Unsupported Input Resolution '0x%08x'x'0x%08x' for SFC.", srcSurface->dwWidth, srcSurface->dwHeight);
             return false;
         }
 
@@ -759,7 +768,6 @@ bool CodechalSfcState::IsSfcOutputSupported(
     if (!MOS_WITHIN_RANGE(srcSurfWidth, m_sfcInterface->m_minWidth, m_sfcInterface->m_maxWidth) ||
         !MOS_WITHIN_RANGE(srcSurfHeight, m_sfcInterface->m_minHeight, m_sfcInterface->m_maxHeight))
     {
-        CODECHAL_DECODE_ASSERTMESSAGE("Unsupported Input Resolution '0x%08x'x'0x%08x' for SFC.", srcSurfWidth, srcSurfHeight);
         return false;
     }
 
@@ -796,7 +804,6 @@ bool CodechalSfcState::IsSfcOutputSupported(
     if ((sourceRegionWidth > srcSurface->dwWidth) ||
         (sourceRegionHeight > srcSurface->dwHeight))
     {
-        CODECHAL_DECODE_ASSERTMESSAGE("Input region is out of bound for SFC.");
         return false;
     }
 
@@ -804,7 +811,6 @@ bool CodechalSfcState::IsSfcOutputSupported(
     if (!MOS_WITHIN_RANGE(dstSurfWidth, m_sfcInterface->m_minWidth, m_sfcInterface->m_maxWidth) ||
         !MOS_WITHIN_RANGE(dstSurfHeight, m_sfcInterface->m_minHeight, m_sfcInterface->m_maxHeight))
     {
-        CODECHAL_DECODE_ASSERTMESSAGE("Unsupported Output Resolution '0x%08x'x'0x%08x' for SFC.", dstSurfWidth, dstSurfHeight);
         return false;
     }
 
@@ -815,7 +821,6 @@ bool CodechalSfcState::IsSfcOutputSupported(
     if ((outputRegionWidth > destSurface->dwWidth) ||
         (outputRegionHeight > destSurface->dwHeight))
     {
-        CODECHAL_DECODE_ASSERTMESSAGE("Output region is out of bound for SFC.");
         return false;
     }
 
@@ -827,7 +832,6 @@ bool CodechalSfcState::IsSfcOutputSupported(
     if (!MOS_WITHIN_RANGE(m_scaleX, m_sfcInterface->m_minScalingRatio, m_sfcInterface->m_maxScalingRatio) ||
         !MOS_WITHIN_RANGE(m_scaleY, m_sfcInterface->m_minScalingRatio, m_sfcInterface->m_maxScalingRatio))
     {
-        CODECHAL_DECODE_ASSERTMESSAGE("Scaling factor not supported by SFC Pipe.");
         return false;
     }
 
