@@ -29,6 +29,7 @@
 #include "codechal_secure_decode_interface.h"
 #include "codechal_decode_vp9.h"
 #include "codechal_mmc_decode_vp9.h"
+#include "hal_oca_interface.h"
 #if USE_CODECHAL_DEBUG_TOOL
 #include <sstream>
 #include <fstream>
@@ -163,17 +164,29 @@ CodechalDecodeVp9 ::CodechalDecodeVp9(
     CodechalHwInterface *   hwInterface,
     CodechalDebugInterface *debugInterface,
     PCODECHAL_STANDARD_INFO standardInfo) : CodechalDecode(hwInterface, debugInterface, standardInfo),
+                                            m_usFrameWidthAlignedMinBlk(0),
+                                            m_usFrameHeightAlignedMinBlk(0),
+                                            m_vp9DepthIndicator(0),
+                                            m_chromaFormatinProfile(0),
+                                            m_dataSize(0),
+                                            m_dataOffset(0),
+                                            m_frameCtxIdx(0),
                                             m_curMvTempBufIdx(0),
                                             m_colMvTempBufIdx(0),
                                             m_copyDataBufferSize(0),
+                                            m_copyDataOffset(0),
+                                            m_copyDataBufferInUse(false),
+                                            m_hcpDecPhase(0),
                                             m_prevFrmWidth(0),
                                             m_prevFrmHeight(0),
                                             m_allocatedWidthInSb(0),
                                             m_allocatedHeightInSb(0),
                                             m_mvBufferSize(0),
+                                            m_resetSegIdBuffer(false),
                                             m_pendingResetPartial(0),
                                             m_saveInterProbs(0),
-                                            m_copyDataBufferInUse(false)
+                                            m_fullProbBufferUpdate(false),
+                                            m_dmemBufferSize(0)
 {
     CODECHAL_DECODE_FUNCTION_ENTER;
 
@@ -197,6 +210,15 @@ CodechalDecodeVp9 ::CodechalDecodeVp9(
     MOS_ZeroMemory(&m_resSegmentIdBuffReset, sizeof(m_resSegmentIdBuffReset));
     MOS_ZeroMemory(&m_resHucSharedBuffer, sizeof(m_resHucSharedBuffer));
     MOS_ZeroMemory(&m_picMhwParams, sizeof(m_picMhwParams));
+    MOS_ZeroMemory(&m_destSurface, sizeof(m_destSurface));
+    MOS_ZeroMemory(&m_lastRefSurface, sizeof(m_lastRefSurface));
+    MOS_ZeroMemory(&m_goldenRefSurface, sizeof(m_goldenRefSurface));
+    MOS_ZeroMemory(&m_altRefSurface, sizeof(m_altRefSurface));
+    MOS_ZeroMemory(&m_resDataBuffer, sizeof(m_resDataBuffer));
+    MOS_ZeroMemory(&m_resCoefProbBuffer, sizeof(m_resCoefProbBuffer));
+    MOS_ZeroMemory(&m_resSyncObject, sizeof(m_resSyncObject));
+    MOS_ZeroMemory(&m_resSyncObjectWaContextInUse, sizeof(m_resSyncObjectWaContextInUse));
+    MOS_ZeroMemory(&m_resSyncObjectVideoContextInUse, sizeof(m_resSyncObjectVideoContextInUse));
 
     m_prevFrameParams.value = 0;
 
@@ -1052,7 +1074,7 @@ MOS_STATUS CodechalDecodeVp9 :: CheckAndCopyBitStream()
             (m_vp9PicParams->FrameWidthMinus1 + 1) * (m_vp9PicParams->FrameHeightMinus1 + 1) * 6;
     }
 
-    if (m_firstExecuteCall) // first exec call
+    if (IsFirstExecuteCall()) // first exec call
     {
         if (m_dataSize < m_vp9PicParams->BSBytesInBuffer)  // Current bitstream buffer is not big enough
         {
@@ -1122,6 +1144,7 @@ MOS_STATUS CodechalDecodeVp9::SetFrameStates ()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
+    PERF_UTILITY_AUTO(__FUNCTION__, PERF_DECODE, PERF_LEVEL_HAL);
     CODECHAL_DECODE_FUNCTION_ENTER;
 
     CODECHAL_DECODE_CHK_NULL_RETURN(m_decodeParams.m_destSurface);
@@ -1142,7 +1165,7 @@ MOS_STATUS CodechalDecodeVp9::SetFrameStates ()
         m_resCoefProbBuffer = *(m_decodeParams.m_coefProbBuffer);
     }
 
-    if (m_firstExecuteCall)
+    if (IsFirstExecuteCall())
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(InitializeBeginFrame());
     }
@@ -1295,6 +1318,7 @@ MOS_STATUS CodechalDecodeVp9 :: DetermineDecodePhase()
 MOS_STATUS CodechalDecodeVp9 :: InitPicStateMhwParams()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    PMOS_RESOURCE usedDummyReference = nullptr;
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
@@ -1372,6 +1396,16 @@ MOS_STATUS CodechalDecodeVp9 :: InitPicStateMhwParams()
     m_picMhwParams.SurfaceParams[0]->ucBitDepthChromaMinus8 = m_vp9PicParams->BitDepthMinus8;
     m_picMhwParams.SurfaceParams[0]->dwUVPlaneAlignment = 8;
 
+    if (MEDIA_IS_WA(m_waTable, WaDummyReference) &&
+        !Mos_ResourceIsNull(&m_dummyReference.OsResource))
+    {
+        usedDummyReference = &m_dummyReference.OsResource;
+    }
+    else
+    {
+        usedDummyReference = &m_destSurface.OsResource;
+    }
+
     // Populate surface param for reference pictures
     if (m_vp9PicParams->PicFlags.fields.frame_type == CODEC_VP9_INTER_FRAME &&
         !m_vp9PicParams->PicFlags.fields.intra_only &&
@@ -1379,6 +1413,19 @@ MOS_STATUS CodechalDecodeVp9 :: InitPicStateMhwParams()
         m_presGoldenRefSurface != nullptr &&
         m_presAltRefSurface != nullptr)
     {
+        if (Mos_ResourceIsNull(m_presLastRefSurface))
+        {
+            m_presLastRefSurface = usedDummyReference;
+        }
+        if (Mos_ResourceIsNull(m_presGoldenRefSurface))
+        {
+            m_presGoldenRefSurface = usedDummyReference;
+        }
+        if (Mos_ResourceIsNull(m_presAltRefSurface))
+        {
+            m_presAltRefSurface = usedDummyReference;
+        }
+
         //MOS_SURFACE lastRefSurface;
         CODECHAL_DECODE_CHK_STATUS_RETURN(MOS_SecureMemcpy(
             &m_lastRefSurface.OsResource,
@@ -1445,19 +1492,13 @@ MOS_STATUS CodechalDecodeVp9 :: InitPicStateMhwParams()
     {
         if (!m_picMhwParams.PipeBufAddrParams->presReferences[i])
         {
-            if (MEDIA_IS_WA(m_waTable, WaDummyReference) &&
-                !Mos_ResourceIsNull(&m_dummyReference.OsResource))
-            {
-                m_picMhwParams.PipeBufAddrParams->presReferences[i] = &m_dummyReference.OsResource;
-            }
-            else
-            {
-                m_picMhwParams.PipeBufAddrParams->presReferences[i] = &(m_destSurface.OsResource);
-            }
+            m_picMhwParams.PipeBufAddrParams->presReferences[i] = usedDummyReference;
         }
     }
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetPipeBufAddr(m_picMhwParams.PipeBufAddrParams));
+#endif
 
     if (m_streamOutEnabled)
     {
@@ -1465,9 +1506,11 @@ MOS_STATUS CodechalDecodeVp9 :: InitPicStateMhwParams()
             &(m_streamOutBuffer[m_streamOutCurrBufIdx]);
     }
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->CheckReferenceList(m_picMhwParams.PipeBufAddrParams));
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetRefrenceSync(m_disableDecodeSyncLock, m_disableLockForTranscode));
+#endif
 
     m_picMhwParams.PipeBufAddrParams->presMfdDeblockingFilterRowStoreScratchBuffer =
         &m_resDeblockingFilterLineRowStoreScratchBuffer;
@@ -1645,6 +1688,14 @@ MOS_STATUS CodechalDecodeVp9 :: UpdatePicStateBuffers(
         }
     }
 
+    if (m_osInterface->osCpInterface->IsHMEnabled())
+    {
+        if (m_secureDecoder && MEDIA_IS_WA(m_hwInterface->GetWaTable(), WaSecureDecodeTDR))
+        {
+            CODECHAL_DECODE_CHK_STATUS_RETURN(m_secureDecoder->InitAuxSurface(&m_destSurface.OsResource, cmdBuffe));
+        }
+    }
+
     CODECHAL_DEBUG_TOOL(
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->DumpBuffer(
             &m_resVp9SegmentIdBuffer,
@@ -1664,6 +1715,7 @@ MOS_STATUS CodechalDecodeVp9 :: DecodeStateLevel()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
+    PERF_UTILITY_AUTO(__FUNCTION__, PERF_DECODE, PERF_LEVEL_HAL);
     CODECHAL_DECODE_FUNCTION_ENTER;
 
     if (m_secureDecoder && m_hcpDecPhase == CodechalHcpDecodePhaseInitialized)
@@ -1680,6 +1732,9 @@ MOS_STATUS CodechalDecodeVp9 :: DecodeStateLevel()
         &cmdBuffer,
         0));
 
+    auto mmioRegisters = m_hwInterface->GetMfxInterface()->GetMmioRegisters(m_vdboxIndex);
+    HalOcaInterface::On1stLevelBBStart(cmdBuffer, *m_osInterface->pOsContext, m_osInterface->CurrentGpuContextHandle, *m_miInterface, *mmioRegisters);
+
     //Frame tracking functionality is called at the start of a command buffer.
     //Called at FE decode phase, since BE decode phase will only construct BE batch buffers.
     CODECHAL_DECODE_CHK_STATUS_RETURN(SendPrologWithFrameTracking(
@@ -1706,6 +1761,8 @@ MOS_STATUS CodechalDecodeVp9 :: DecodePrimitiveLevel()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
+    PERF_UTILITY_AUTO(__FUNCTION__, PERF_DECODE, PERF_LEVEL_HAL);
+
     CODECHAL_DECODE_FUNCTION_ENTER;
 
     // Bitstream is incomplete, don't do any decoding work.
@@ -1845,6 +1902,8 @@ MOS_STATUS CodechalDecodeVp9 :: DecodePrimitiveLevel()
 
     uint32_t renderingFlags = m_videoContextUsesNullHw;
 
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+
     //submit command buffer
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
         m_osInterface,
