@@ -166,7 +166,7 @@ struct EncodeAvcPar
     uint8_t                     SearchControl;
     uint8_t                     BSearchControl;
     uint8_t                     BiMixDisable;
-    uint8_t                     BiWeight;
+    uint32_t                    BiWeight;
     bool                        DisableExtendedMvCostRange;
     bool                        EnableAdaptiveSearch;
     bool                        EnableFBRBypass;
@@ -203,8 +203,35 @@ struct EncodeAvcPar
     bool                        VDEncPerfMode;
     bool                        VdencExtPakObjDisable;
     bool                        PPMVDisable;
-    uint8_t                     ImePredOverlapThr;
     uint8_t                     LeftNbrPelMode;
+    uint8_t                     DisPSubPartMask;
+    uint8_t                     DisPSubMbMask;
+    uint8_t                     DisBSubPartMask;
+    uint8_t                     DisBSubMbMask;
+    uint8_t                     ImePredOverlapThr;
+    uint8_t                     MBSizeEstScalingRatioINTRA;
+    bool                        IntraMBHdrScaleFactor;
+    uint8_t                     MBSizeEstScalingRatioINTER;
+    bool                        InterMBHdrScaleFactor;
+    uint8_t                     PFrameMaxNumImePred;
+    uint8_t                     BFrameMaxNumImePred;
+    uint8_t                     HMERefWindowSize;
+    uint8_t                     IMELeftPredDep;
+    uint8_t                     NumFMECandCheck;
+    uint8_t                     PFrameImePredLargeSW;
+    uint8_t                     BFrameImePredLargeSW;
+    bool                        RdoChromaEnable;
+    uint16_t                    Intra4x4ModeMask;
+    uint16_t                    Intra8x8ModeMask;
+    bool                        RdoIntraChromaSearch;
+    uint8_t                     Intra16x16ModeMask;
+    uint8_t                     InitMBBudgetTr4x4;
+    bool                        ROIEnable;
+    uint8_t                     PFrameZeroCbfEn;
+    uint8_t                     BFrameZeroCbfEn;
+    uint8_t                     ForceIPCMMinQP;
+    uint8_t                     IntraTr4x4Percent;
+    bool                        MultiPassHmeEnable;
 
     // PAK Params
     uint8_t                     RoundingIntra;
@@ -1801,6 +1828,14 @@ protected:
     //!
     MOS_STATUS PopulateConstParam();
 
+    //!
+    //! \brief    Populate target usage as the first parameter of dumped par file
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS PopulateTargetUsage();
+
     //!
     //! \brief    Set MHW_VDBOX_AVC_IMG_STATE parameter
     //!
@@ -1921,7 +1956,8 @@ protected:
         PMOS_COMMAND_BUFFER cmdBuffer,
         PMHW_BATCH_BUFFER   secondLevelBatchBuffer) { return MOS_STATUS_SUCCESS; }
 
-    EncodeAvcPar *m_avcPar = nullptr;  //!< AVC PAR parameters
+    EncodeAvcPar *m_avcPar             = nullptr;  //!< AVC PAR parameters
+    bool         m_populateTargetUsage = false;
 #endif
 
     //!
