@@ -84,8 +84,8 @@ typedef struct _HUC_AUX_BUFFER
 } HUC_AUX_BUFFER, *PHUC_AUX_BUFFER;
 #define CODECHAL_ENCODE_VP9_FRAME_HEADER_SIZE                   4096
 #define CODECHAL_ENCODE_VP9_MAX_NAL_UNIT_TYPE                   1   // only support one NAL unit for uncompressed header
-#define ENCODE_VP9_8K_PIC_WIDTH     7680
-#define ENCODE_VP9_8K_PIC_HEIGHT    7680
+#define ENCODE_VP9_8K_PIC_WIDTH     8192
+#define ENCODE_VP9_8K_PIC_HEIGHT    8192
 #define ENCODE_VP9_16K_PIC_WIDTH     16384
 #define ENCODE_VP9_16K_PIC_HEIGHT    16384
 
@@ -1658,7 +1658,7 @@ public:
     bool                                        m_adaptiveRepakSupported = false;
     bool                                        m_tsEnabled = false;
     bool                                        m_superFrameHucPass = false;
-    bool                                        m_storeSingleTaskPhaseSupported; //For dynamic scaling, need to save the original state
+    bool                                        m_storeSingleTaskPhaseSupported = false; //For dynamic scaling, need to save the original state
     uint8_t                                     m_refFrameFlags = 0;
     uint8_t                                     m_numRefFrames = 0;
     uint8_t                                     m_dysRefFrameFlags = 0;
@@ -1735,7 +1735,7 @@ public:
     bool                                        m_prevFrameSegEnabled = false;
     uint32_t                                    m_vdencPictureState2ndLevelBatchBufferSize = 0;
     uint16_t                                    m_sadQpLambda = 0;
-    uint16_t                                    m_rdQpLambda;
+    uint16_t                                    m_rdQpLambda = 0;
     uint16_t                                    m_hucPicStateOffset = 0;
     uint16_t                                    m_hucSlbbSize = 0;
     uint8_t                                     m_vdencMvCosts[12] = { 0 };
@@ -1768,9 +1768,9 @@ public:
 
     uint32_t                                    m_maxTileNumber = 1;
 
-    uint32_t                                    m_bitDepth;
-    uint8_t                                     m_chromaFormat;
-    uint32_t                                    m_sizeOfSseSrcPixelRowStoreBufferPerLcu;
+    uint32_t                                    m_bitDepth = 0;
+    uint8_t                                     m_chromaFormat = 0;
+    uint32_t                                    m_sizeOfSseSrcPixelRowStoreBufferPerLcu = 0;
     PCODECHAL_CMD_INITIALIZER                   m_hucCmdInitializer = nullptr;
 
 protected:
@@ -1896,6 +1896,8 @@ public:
 
     virtual MOS_STATUS SetPictureStructs();
 
+    virtual MOS_STATUS SetRowstoreCachingOffsets();
+
     //!
     //! \brief      User feature key report
     //!
