@@ -26,6 +26,7 @@
 #include "mhw_utilities.h"
 #include "mhw_render.h"
 #include "mhw_state_heap.h"
+#include "hal_oca_interface.h"
 
 #define MHW_NS_PER_TICK_RENDER_ENGINE 80  // 80 nano seconds per tick in render engine
 
@@ -66,8 +67,8 @@ MOS_STATUS Mhw_AddResourceToCmd_GfxAddress(
     MHW_CHK_STATUS(pOsInterface->pfnRegisterResource(
         pOsInterface,
         pParams->presResource,
-        pParams->bIsWritable,
-        pParams->bIsWritable));
+        pParams->bIsWritable ? true : false,
+        pParams->bIsWritable ? true : false));
 
     dwAlign = ( 1 << pParams->dwLsbNum);
     dwMask  = (-1 << pParams->dwLsbNum);
@@ -180,8 +181,8 @@ MOS_STATUS Mhw_AddResourceToCmd_PatchList(
     MHW_CHK_STATUS(pOsInterface->pfnRegisterResource(
         pOsInterface,
         pParams->presResource,
-        pParams->bIsWritable,
-        pParams->bIsWritable));
+        pParams->bIsWritable ? true : false,
+        pParams->bIsWritable ? true : false));
 
     GpuContext = pOsInterface->pfnGetGpuContext(pOsInterface);
     iAllocationIndex = pOsInterface->pfnGetResourceAllocationIndex(pOsInterface, pParams->presResource);
@@ -223,6 +224,7 @@ MOS_STATUS Mhw_AddResourceToCmd_PatchList(
     PatchEntryParams.shiftAmount      = pParams->shiftAmount;
     PatchEntryParams.shiftDirection   = pParams->shiftDirection;
     PatchEntryParams.offsetInSSH      = pParams->dwOffsetInSSH;
+    PatchEntryParams.cmdBuffer        = pCmdBuffer;
 
     // Add patch entry to patch the address field for this command
     MHW_CHK_STATUS(pOsInterface->pfnSetPatchEntry(
@@ -251,6 +253,7 @@ MOS_STATUS Mhw_AddResourceToCmd_PatchList(
         PatchEntryParams.shiftAmount      = pParams->shiftAmount;
         PatchEntryParams.shiftDirection   = pParams->shiftDirection;
         PatchEntryParams.offsetInSSH      = pParams->dwOffsetInSSH;
+        PatchEntryParams.cmdBuffer        = pCmdBuffer;
 
         if(dwLsbNum)
         {
@@ -330,7 +333,8 @@ finish:
 //!
 MOS_STATUS Mhw_SendGenericPrologCmd (
     PMOS_COMMAND_BUFFER         pCmdBuffer,
-    PMHW_GENERIC_PROLOG_PARAMS  pParams)
+    PMHW_GENERIC_PROLOG_PARAMS  pParams,
+    MHW_MI_MMIOREGISTERS       *pMmioReg)
 {
     PMOS_INTERFACE                  pOsInterface;
     MhwMiInterface                  *pMiInterface;
@@ -374,7 +378,10 @@ MOS_STATUS Mhw_SendGenericPrologCmd (
                 GpuContext == MOS_GPU_CONTEXT_VDBOX2_VIDEO  ||
                 GpuContext == MOS_GPU_CONTEXT_VDBOX2_VIDEO2 ||
                 GpuContext == MOS_GPU_CONTEXT_VDBOX2_VIDEO3 ||
-                GpuContext == MOS_GPU_CONTEXT_VEBOX)
+                GpuContext == MOS_GPU_CONTEXT_VEBOX         ||
+                GpuContext == MOS_GPU_CONTEXT_VIDEO5        ||
+                GpuContext == MOS_GPU_CONTEXT_VIDEO6        ||
+                GpuContext == MOS_GPU_CONTEXT_VIDEO7        )
         {
             MHW_CHK_STATUS(pMiInterface->AddWatchdogTimerStartCmd(pCmdBuffer));
         }
@@ -439,6 +446,16 @@ MOS_STATUS Mhw_SendGenericPrologCmd (
 
     MHW_CHK_STATUS(pMiInterface->AddProtectedProlog(pCmdBuffer));
 
+    if (pMmioReg)
+    {
+        HalOcaInterface::On1stLevelBBStart(
+            *pCmdBuffer,
+            *pOsInterface->pOsContext,
+            pOsInterface->CurrentGpuContextHandle,
+            *pMiInterface,
+            *pMmioReg);
+    }
+
 finish:
     return eStatus;
 }
