@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2017, Intel Corporation
+* Copyright (c) 2009-2019, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -202,7 +202,7 @@ void VpHal_GetCscMatrix(
     float*                      pfCscInOffset,                                  // [out] [3x1] Input Offset matrix
     float*                      pfCscOutOffset)                                 // [out] [3x1] Output Offset matrix
 {
-    float   fCscMatrix[12];
+    float   fCscMatrix[12] = {0};
     int32_t i;
 
     KernelDll_GetCSCMatrix(
@@ -402,8 +402,8 @@ float VpHal_Lanczos(float x, uint32_t dwNumEntries, float fLanczosT)
 //!           Expected Surface Width
 //! \param    [in] dwHeight
 //!           Expected Surface Height
-//! \param    [in] bCompressed
-//!           Compressed surface or not
+//! \param    [in] bCompressible
+//!           Surface being compressible or not
 //! \param    [in] CompressionMode
 //!           Compression Mode
 //! \param    [out] pbAllocated
@@ -420,7 +420,7 @@ MOS_STATUS VpHal_ReAllocateSurface(
     MOS_TILE_TYPE           DefaultTileType,
     uint32_t                dwWidth,
     uint32_t                dwHeight,
-    bool                    bCompressed,
+    bool                    bCompressible,
     MOS_RESOURCE_MMC_MODE   CompressionMode,
     bool*                   pbAllocated)
 {
@@ -436,14 +436,14 @@ MOS_STATUS VpHal_ReAllocateSurface(
     eStatus      = MOS_STATUS_SUCCESS;
     *pbAllocated = false;
 
-    // bCompressed should be compared with bCompressible since it is inited by bCompressible in previous call
+    // bCompressible should be compared with bCompressible since it is inited by bCompressible in previous call
     // TileType of surface should be compared since we need to reallocate surface if TileType changes
     if (!Mos_ResourceIsNull(&pSurface->OsResource)        &&
         (pSurface->dwWidth         == dwWidth)            &&
-        (pSurface->dwHeight        == dwHeight)            &&
-        (pSurface->Format          == Format)            &&
-        (pSurface->bCompressible   == bCompressed)        &&
-        (pSurface->CompressionMode == CompressionMode)  &&
+        (pSurface->dwHeight        == dwHeight)           &&
+        (pSurface->Format          == Format)             &&
+        (pSurface->bCompressible   == bCompressible)      &&
+        (pSurface->CompressionMode == CompressionMode)    &&
         (pSurface->TileType        == DefaultTileType))
     {
         goto finish;
@@ -456,7 +456,7 @@ MOS_STATUS VpHal_ReAllocateSurface(
     AllocParams.dwWidth         = dwWidth;
     AllocParams.dwHeight        = dwHeight;
     AllocParams.Format          = Format;
-    AllocParams.bIsCompressed   = bCompressed;
+    AllocParams.bIsCompressible = bCompressible;
     AllocParams.CompressionMode = CompressionMode;
     AllocParams.pBufName        = pSurfaceName;
     AllocParams.dwArraySize     = 1;
@@ -668,6 +668,12 @@ VPHAL_COLORPACK VpHal_GetSurfaceColorPack (
 
     switch (Format)
     {
+        case Format_Y8:
+        case Format_Y16S:
+        case Format_Y16U:
+            ColorPack = VPHAL_COLORPACK_400;
+            break;
+
         case Format_IMC1:
         case Format_IMC2:
         case Format_IMC3:
@@ -717,6 +723,14 @@ VPHAL_COLORPACK VpHal_GetSurfaceColorPack (
             ColorPack = VPHAL_COLORPACK_444;
             break;
 
+        case Format_400P:
+            ColorPack = VPHAL_COLORPACK_400;
+            break;
+
+        case Format_411P:
+            ColorPack = VPHAL_COLORPACK_411;
+            break;
+
         default:
             VPHAL_PUBLIC_ASSERTMESSAGE("Input format color pack unknown.");
             ColorPack = VPHAL_COLORPACK_UNKNOWN;
@@ -978,3 +992,26 @@ uint16_t VpHal_FloatToHalfFloat(
 
     return outFloat.value;
 }
+
+MOS_SURFACE VpHal_ConvertVphalSurfaceToMosSurface(PVPHAL_SURFACE pSurface)
+{
+    VPHAL_PUBLIC_ASSERT(pSurface);
+
+    MOS_SURFACE outSurface;
+    MOS_ZeroMemory(&outSurface, sizeof(MOS_SURFACE));
+    outSurface.OsResource      = pSurface->OsResource;
+    outSurface.Format          = pSurface->Format;
+    outSurface.dwWidth         = pSurface->dwWidth;
+    outSurface.dwHeight        = pSurface->dwHeight;
+    outSurface.TileType        = pSurface->TileType;
+    outSurface.dwDepth         = pSurface->dwDepth;
+    outSurface.dwPitch         = pSurface->dwPitch;
+    outSurface.dwSlicePitch    = pSurface->dwSlicePitch;
+    outSurface.dwOffset        = pSurface->dwOffset;
+    outSurface.bCompressible   = pSurface->bCompressible;
+    outSurface.bIsCompressed   = pSurface->bIsCompressed;
+    outSurface.CompressionMode = pSurface->CompressionMode;
+    outSurface.CompressionFormat = pSurface->CompressionFormat;
+
+    return outSurface;
+}
