@@ -2134,7 +2134,11 @@ typedef struct _VPHAL_VEBOX_EXEC_STATE
 //!
 #define REQUEST_VEBOX_SPECULATIVE_COPY(_a)            (_a->bSpeculativeCopy = true)
 #define IS_VEBOX_SPECULATIVE_COPY_REQUESTED(_a)       (_a->bSpeculativeCopy == true)
-#define SET_VEBOX_EXECUTION_MODE(_a, _Mode)           (_a->Mode = _Mode)
+#define SET_VEBOX_EXECUTION_MODE(_a, _Mode)                           \
+    {                                                                 \
+        (_a->Mode = _Mode);                                           \
+        VPHAL_RENDER_NORMALMESSAGE("VEBOX_EXECUTION_MODE %d", _Mode); \
+    }
 #define IS_VEBOX_EXECUTION_MODE_PARALLEL_CAPABLE(_a)  (_a->bEnable == true)
 #define IS_VEBOX_EXECUTION_MODE_0(_a)                 (_a->Mode == VEBOX_EXEC_MODE_0)
 #define IS_VEBOX_EXECUTION_MODE_0_TO_2(_a)            (_a->Mode == VEBOX_EXEC_MODE_0_TO_2)
@@ -2559,6 +2563,8 @@ MOS_STATUS VpHal_CommonSetBufferSurfaceForHwAccess(
 //!             Pointer to GPGPU walker parameters
 //! \param      [in] KernelID
 //!             VP Kernel ID
+//! \param      [in] bLastSubmission
+//!             whether it is the last submission
 //! \return     MOS_STATUS
 //!
 MOS_STATUS VpHal_RndrCommonSubmitCommands(
@@ -2567,7 +2573,8 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
     bool                                bNullRendering,
     PMHW_WALKER_PARAMS                  pWalkerParams,
     PMHW_GPGPU_WALKER_PARAMS            pGpGpuWalkerParams,
-    VpKernelID                          KernelID);
+    VpKernelID                          KernelID,
+    bool                                bLastSubmission);
 
 //!
 //! \brief      Submit commands for rendering
@@ -2586,6 +2593,12 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
 //!             Pointer to pStatusTableUpdateParams
 //! \param      [in] KernelID
 //!             VP Kernel ID
+//! \param      [in] FcKernelCount
+//!             VP FC Kernel Count
+//! \param      [in] FcKernelList
+//!             VP FC Kernel List
+//! \param      [in] bLastSubmission
+//!             whether it is the last submission
 //! \return     MOS_STATUS
 //!
 MOS_STATUS VpHal_RndrSubmitCommands(
@@ -2594,8 +2607,11 @@ MOS_STATUS VpHal_RndrSubmitCommands(
     bool                                bNullRendering,
     PMHW_WALKER_PARAMS                  pWalkerParams,
     PMHW_GPGPU_WALKER_PARAMS            pGpGpuWalkerParams,
-    PSTATUS_TABLE_UPDATE_PARAMS            pStatusTableUpdateParams,
-    VpKernelID                          KernelID);
+    PSTATUS_TABLE_UPDATE_PARAMS         pStatusTableUpdateParams,
+    VpKernelID                          KernelID,
+    int                                 FcKernelCount,
+    int                                 *FcKernelList,
+    bool                                bLastSubmission);
 
 //!
 //! \brief      Is Alignment WA needed
