@@ -50,6 +50,9 @@
 #define VPHAL_COMP_SAMPLER_LUMAKEY  4
 #define VPHAL_COMP_MAX_SAMPLER      (VPHAL_COMP_SAMPLER_NEAREST | VPHAL_COMP_SAMPLER_BILINEAR | VPHAL_COMP_SAMPLER_LUMAKEY)
 
+#define VPHAL_SAMPLER_Y                 1
+#define VPHAL_SAMPLER_U                 2
+#define VPHAL_SAMPLER_V                 3
 #define VPHAL_COMP_COMPUTE_WALKER_THREAD_SPACE_WIDTH    1
 #define VPHAL_COMP_COMPUTE_WALKER_THREAD_SPACE_HEIGHT   1
 #define VPHAL_COMP_COMPUTE_WALKER_THREAD_SPACE_DEPTH    1
@@ -650,22 +653,53 @@ protected:
     virtual MOS_STATUS IsCompositeParamsValid(
         const VPHAL_COMPOSITE_PARAMS& CompositeParams);
 
-private:
     //!
-    //! \brief    Prepare phases for composite and determine intermediate colorspace
-    //! \param    [in] pcRenderParams
-    //!           Pointer to Render parameters
-    //! \param    [in] ppSources
-    //!           Pointer to the address of Source Surfaces
-    //! \param    [in] iSources
-    //!           Count of Source Surfaces
-    //! \return   VPHAL_CSPACE
-    //!           Return intermediate colorspace
+    //! \brief    Get Sampler Index associated with a surface state for composite
+    //! \param    [in] pSurface
+    //!           point to input Surface
+    //! \param    [in] pEntry
+    //!           Pointer to Surface state
+    //! \param    [out] pSamplerIndex
+    //!           Pointer to Sampler Index
+    //! \param    [out] pSamplerType
+    //!           Pointer to Sampler Type
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise MOS_STATUS_UNKNOWN
     //!
-    VPHAL_CSPACE PrepareCSC(
-        PCVPHAL_RENDER_PARAMS   pcRenderParams,
-        PVPHAL_SURFACE          *ppSources,
-        int32_t                 iSources);
+    virtual MOS_STATUS GetSamplerIndex(
+        PVPHAL_SURFACE                      pSurface,
+        PRENDERHAL_SURFACE_STATE_ENTRY      pEntry,
+        int32_t*                            pSamplerIndex,
+        PMHW_SAMPLER_TYPE                   pSamplerType);
+
+    //!
+    //! \brief    Check whether the 3Dsampler use for Y plane
+    //! \param    [in] SamplerID
+    //!           sampler ID
+    //! \return   bool
+    //!           Return true if the 3Dsampler use for Y plane, otherwise fase
+    //!
+    virtual bool IsSamplerIDForY(
+        int32_t                            SamplerID);
+
+    //! \brief    set Sampler status
+    //! \param    [in] pSurface
+    //!           point to input Surface
+    //! \param    [in] Layer
+    //!           composition layer
+    //! \param    [in] pStatic
+    //!           Pointer to static data
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise MOS_STATUS_UNKNOWN
+    //!
+    virtual MOS_STATUS Set3DSamplerStatus(
+        PVPHAL_SURFACE                 pSurface,
+        uint8_t                        Layer,
+        MEDIA_OBJECT_KA2_STATIC_DATA   *pStatic)
+    {
+        // Just need the sub class to implement if it is needed;
+        return MOS_STATUS_SUCCESS;
+    }
 
     //!
     //! \brief    Prepare phases for composite and allocate intermediate buffer for rendering
@@ -678,33 +712,11 @@ private:
     //! \return   bool
     //!           Return true if multiple phases, otherwise false
     //!
-    bool PreparePhases(
+    virtual bool PreparePhases(
         PCVPHAL_RENDER_PARAMS       pcRenderParams,
         PVPHAL_SURFACE              *ppSources,
         int32_t                     iSources);
 
-    //!
-    //! \brief    Composite multiple phase rendering
-    //! \details  Composite render with multiple phases. In some cases we cannot process composition just in one phase
-    //!           for example, if the input streams count is 9 (1 primary + 8 substreams), we need to postpone the
-    //!           9th stream to next second phase due to the input count limitation of current composition kernel.
-    //! \param    [in] pcRenderParams
-    //!           Pointer to VPHAL_RENDER_PARAMS
-    //! \param    [in] ppSources
-    //!           Pointer to PVPHAL_SURFACE, array of input surfaces
-    //! \param    [in] iSources
-    //!           constant int iSource indicating the size of ppSources
-    //! \param    [in] pOutput
-    //!           Pointer to VPHAL_SURFACE, output surface for the overall composition process
-    //! \return   MOS_STATUS
-    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
-    //!
-    MOS_STATUS RenderMultiPhase(
-        PCVPHAL_RENDER_PARAMS   pcRenderParams,
-        PVPHAL_SURFACE          *ppSources,
-        const int32_t           iSources,
-        PVPHAL_SURFACE          pOutput);
-
     //!
     //! \brief    Reset composite rendering parameters for the current phase
     //! \param    [in,out] pComposite
@@ -740,6 +752,45 @@ private:
         PVPHAL_COMPOSITE_PARAMS     pComposite,
         PVPHAL_SURFACE              pTarget);
 
+private:
+    //!
+    //! \brief    Prepare phases for composite and determine intermediate colorspace
+    //! \param    [in] pcRenderParams
+    //!           Pointer to Render parameters
+    //! \param    [in] ppSources
+    //!           Pointer to the address of Source Surfaces
+    //! \param    [in] iSources
+    //!           Count of Source Surfaces
+    //! \return   VPHAL_CSPACE
+    //!           Return intermediate colorspace
+    //!
+    VPHAL_CSPACE PrepareCSC(
+        PCVPHAL_RENDER_PARAMS   pcRenderParams,
+        PVPHAL_SURFACE          *ppSources,
+        int32_t                 iSources);
+
+    //!
+    //! \brief    Composite multiple phase rendering
+    //! \details  Composite render with multiple phases. In some cases we cannot process composition just in one phase
+    //!           for example, if the input streams count is 9 (1 primary + 8 substreams), we need to postpone the
+    //!           9th stream to next second phase due to the input count limitation of current composition kernel.
+    //! \param    [in] pcRenderParams
+    //!           Pointer to VPHAL_RENDER_PARAMS
+    //! \param    [in] ppSources
+    //!           Pointer to PVPHAL_SURFACE, array of input surfaces
+    //! \param    [in] iSources
+    //!           constant int iSource indicating the size of ppSources
+    //! \param    [in] pOutput
+    //!           Pointer to VPHAL_SURFACE, output surface for the overall composition process
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    MOS_STATUS RenderMultiPhase(
+        PCVPHAL_RENDER_PARAMS   pcRenderParams,
+        PVPHAL_SURFACE          *ppSources,
+        const int32_t           iSources,
+        PVPHAL_SURFACE          pOutput);
+
     //!
     //! \brief    Perform multiple layer composite operation in one phase
     //! \details  Perform multiple layer composite operation in one phase(scaling, blending,
@@ -1010,10 +1061,6 @@ private:
     RENDERHAL_KERNEL_PARAM          m_KernelParams;
     int32_t                         m_ThreadCountPrimary;
 
-    // Intermediate surface (multiple phase / constriction support)
-    VPHAL_SURFACE                   m_Intermediate;
-    // Rotation output intermediate surface
-    VPHAL_SURFACE                   m_Intermediate2;
     // CMFC CSC Coefficient surface
     VPHAL_SURFACE                   m_CmfcCoeff;
     RENDERHAL_SURFACE               m_RenderHalCmfcCoeff;
@@ -1054,6 +1101,8 @@ protected:
 
     static const int                AVS_CACHE_SIZE = 4;           //!< AVS coefficients cache size
     AvsCoeffsCache<AVS_CACHE_SIZE>  m_AvsCoeffsCache;             //!< AVS coefficients calculation is expensive, add cache to mitigate
+    VPHAL_SURFACE                   m_Intermediate;               //!< Intermediate surface (multiple phase / constriction support)
+    VPHAL_SURFACE                   m_Intermediate2;              //!< Rotation output intermediate surface
 };
 
 typedef CompositeState * PCComposite;
