@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2018, Intel Corporation
+* Copyright (c) 2011-2019, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -202,19 +202,25 @@ void VpHal_SaveRestorePrimaryFwdRefs(
 //! \details  The surface rects and width/height need to be aligned according to the surface format
 //! \param    [in,out] pSurface
 //!           Pointer to the surface
+//! \param    [in] formatForDstRect
+//!           Format for Dst Rect
 //! \return   MOS_STATUS
 //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
 //!
 MOS_STATUS VpHal_RndrRectSurfaceAlignment(
-    PVPHAL_SURFACE       pSurface)
+    PVPHAL_SURFACE       pSurface,
+    MOS_FORMAT           formatForDstRect)
 {
     uint16_t   wWidthAlignUnit;
     uint16_t   wHeightAlignUnit;
+    uint16_t   wWidthAlignUnitForDstRect;
+    uint16_t   wHeightAlignUnitForDstRect;
     MOS_STATUS eStatus;
 
     eStatus = MOS_STATUS_SUCCESS;
 
     VpHal_RndrGetAlignUnit(&wWidthAlignUnit, &wHeightAlignUnit, pSurface->Format);
+    VpHal_RndrGetAlignUnit(&wWidthAlignUnitForDstRect, &wHeightAlignUnitForDstRect, formatForDstRect);
 
     // The source rectangle is floored to the aligned unit to
     // get rid of invalid data(ex: an odd numbered src rectangle with NV12 format
@@ -227,11 +233,11 @@ MOS_STATUS VpHal_RndrRectSurfaceAlignment(
 
     // The Destination rectangle is rounded to the upper alignment unit to prevent the loss of
     // data which was present in the source rectangle
-    pSurface->rcDst.bottom = MOS_ALIGN_CEIL((uint32_t)pSurface->rcDst.bottom, wHeightAlignUnit);
-    pSurface->rcDst.right  = MOS_ALIGN_CEIL((uint32_t)pSurface->rcDst.right, wWidthAlignUnit);
+    pSurface->rcDst.bottom = MOS_ALIGN_CEIL((uint32_t)pSurface->rcDst.bottom, wHeightAlignUnitForDstRect);
+    pSurface->rcDst.right  = MOS_ALIGN_CEIL((uint32_t)pSurface->rcDst.right, wWidthAlignUnitForDstRect);
 
-    pSurface->rcDst.top    = MOS_ALIGN_FLOOR((uint32_t)pSurface->rcDst.top, wHeightAlignUnit);
-    pSurface->rcDst.left   = MOS_ALIGN_FLOOR((uint32_t)pSurface->rcDst.left, wWidthAlignUnit);
+    pSurface->rcDst.top    = MOS_ALIGN_FLOOR((uint32_t)pSurface->rcDst.top, wHeightAlignUnitForDstRect);
+    pSurface->rcDst.left   = MOS_ALIGN_FLOOR((uint32_t)pSurface->rcDst.left, wWidthAlignUnitForDstRect);
 
     if (pSurface->SurfType == SURF_OUT_RENDERTARGET)
     {
@@ -561,6 +567,13 @@ MOS_STATUS VphalRenderer::ProcessRenderParameter(
     pRender[VPHAL_RENDER_ID_COMPOSITE]->SetStatusReportParams(this, pRenderParams);
     pRender[VPHAL_RENDER_ID_VEBOX+uiCurrentChannel]->SetStatusReportParams(this, pRenderParams);
 
+    // Decide whether Hdr path should be chosen.
+    VPHAL_RENDER_CHK_STATUS(GetHdrPathNeededFlag(pRenderParams, pRenderPassData));
+    if (pRenderPassData->bHdrNeeded)
+    {
+        VPHAL_RNDR_SET_STATUS_REPORT_PARAMS(pHdrState, this, pRenderParams);
+    }
+
     VPHAL_RNDR_SET_STATUS_REPORT_PARAMS(&Align16State, this, pRenderParams);
     // Loop through the sources
     for (uiIndex = 0;
@@ -614,7 +627,7 @@ MOS_STATUS VphalRenderer::ProcessRenderParameter(
             pRenderPassData->uiPrimaryIndex     = uiIndex;
 
             // align rectangle and source surface
-            VPHAL_RENDER_CHK_STATUS(VpHal_RndrRectSurfaceAlignment(pSrcSurface));
+            VPHAL_RENDER_CHK_STATUS(VpHal_RndrRectSurfaceAlignment(pSrcSurface, pRenderParams->pTarget[0] ? pRenderParams->pTarget[0]->Format : pSrcSurface->Format));
 
             // update max Src rect in both pRenderer and primary surface
             VpHal_RenderInitMaxRect(this, pSrcSurface);
@@ -636,6 +649,7 @@ MOS_STATUS VphalRenderer::ProcessRenderParameter(
         // Check if Slice Shutdown can be enabled
         // Vebox performance is not impacted by slice shutdown
         if (!(pPrimarySurface == nullptr ||                                      // Valid Layer
+            pRenderPassData->bHdrNeeded  ||                                      // HDR Disabled
             pRenderParams->Component == COMPONENT_VPreP))                        // VpostP usage
         {
             bSliceReconfig = true;
@@ -672,9 +686,7 @@ MOS_STATUS VphalRenderer::RenderPass(
     PVPHAL_RENDER_PARAMS    pRenderParams)
 {
     MOS_STATUS              eStatus;
-    uint32_t                uiIndex;                                            // Current source index
-    uint32_t                uiSources;                                          // Number of Sources
-    PVPHAL_SURFACE          pSrcSurface;                                        // Current source surface
+    uint32_t                uiIndex_in;                                         // Current source index
     uint32_t                uiIndex_out;                                        // current target index
     PVPHAL_VEBOX_EXEC_STATE pVeboxExecState;
     RenderpassData          RenderPassData;
@@ -682,8 +694,10 @@ MOS_STATUS VphalRenderer::RenderPass(
     VPHAL_RENDER_ASSERT(m_pRenderHal);
 
     eStatus                 = MOS_STATUS_SUCCESS;
+    uiIndex_in              = 0;
+    uiIndex_out             = 0;
     pVeboxExecState         = &VeboxExecState[uiCurrentChannel];
-    pSrcSurface             = nullptr;
+    MOS_ZeroMemory(&RenderPassData, sizeof(RenderPassData));
 
     RenderPassData.AllocateTempOutputSurfaces();
     RenderPassData.bCompNeeded      = true;
@@ -695,86 +709,87 @@ MOS_STATUS VphalRenderer::RenderPass(
     VPHAL_RENDER_CHK_STATUS(ProcessRenderParameter(pRenderParams, &RenderPassData));
 
     // Loop through the sources
-    for (uiSources = 0, uiIndex = 0;
-         uiSources < pRenderParams->uSrcCount && uiIndex < VPHAL_MAX_SOURCES;
-         uiIndex++)
+    for (uiIndex_in = 0; uiIndex_in < pRenderParams->uSrcCount; uiIndex_in++)
     {
-        pSrcSurface = pRenderParams->pSrc[uiIndex];
-
-        if (pSrcSurface == nullptr)
+        if (pRenderParams->pSrc[uiIndex_in] == nullptr)
         {
             continue;
         }
 
-        uiSources++;
-
         //------------------------------------------
         VPHAL_RNDR_DUMP_SURF(
-            this, uiIndex, VPHAL_DBG_DUMP_TYPE_PRE_ALL, pSrcSurface);
+            this, uiIndex_in, VPHAL_DBG_DUMP_TYPE_PRE_ALL, pRenderParams->pSrc[uiIndex_in]);
         //------------------------------------------
 
-        RenderPassData.pOriginalSrcSurface  = pSrcSurface;
-        RenderPassData.pSrcSurface          = pSrcSurface;
-        RenderPassData.uiSrcIndex           = uiIndex;
+        RenderPassData.pOriginalSrcSurface  = pRenderParams->pSrc[uiIndex_in];
+        RenderPassData.pSrcSurface          = pRenderParams->pSrc[uiIndex_in];
+        RenderPassData.uiSrcIndex           = uiIndex_in;
 
-        if (VpHal_RndrIsFast1toNSupport(&Fast1toNState, pRenderParams, pSrcSurface))
+        if (VpHal_RndrIsFast1toNSupport(&Fast1toNState, pRenderParams, pRenderParams->pSrc[uiIndex_in]))
         {
             // new 1toN path for multi ouput with scaling only case.
             VPHAL_RENDER_NORMALMESSAGE("Enter fast 1to N render.");
             VPHAL_RENDER_CHK_STATUS(RenderFast1toNComposite(pRenderParams, &RenderPassData));
-            UpdateReport(pRenderParams, &RenderPassData);
         }
         else
         {
             // loop through the dst for every src input.
-            for (uiIndex_out = 0;
-                 uiIndex_out < pRenderParams->uDstCount;
-                 uiIndex_out++)
+            // backup the render params to execute as dst_count=1 to compatible with legacy logic.
+            VPHAL_RENDER_PARAMS StoreRenderParams = *pRenderParams;
+            pRenderParams->uDstCount              = 1;
+            for (uiIndex_out = 0; uiIndex_out < StoreRenderParams.uDstCount; uiIndex_out++)
             {
-                VPHAL_RENDER_PARAMS     TPRenderParams;
-                TPRenderParams  = *pRenderParams;
-                if (pRenderParams->pTarget[uiIndex_out] == nullptr)
+                if (StoreRenderParams.pTarget[uiIndex_out] == nullptr)
                 {
                     continue;
                 }
-                // update the first target point, set the dst_count as 1 to compatible with legacy path
-                TPRenderParams.pTarget[0]                = pRenderParams->pTarget[uiIndex_out];
-                TPRenderParams.bUserPrt_16Align[0]       = pRenderParams->bUserPrt_16Align[uiIndex_out];
-                TPRenderParams.uDstCount                 = 1;
-                if (pRenderParams->uDstCount > 1)
+                // update the first target point
+                pRenderParams->pTarget[0]                = StoreRenderParams.pTarget[uiIndex_out];
+                pRenderParams->pTarget[0]->b16UsrPtr     = StoreRenderParams.pTarget[uiIndex_out]->b16UsrPtr;
+                if (StoreRenderParams.uDstCount > 1)
                 {
                     // for multi output, support different scaling ratio but doesn't support cropping.
-                    RenderPassData.pSrcSurface->rcDst.top    = TPRenderParams.pTarget[0]->rcSrc.top;
-                    RenderPassData.pSrcSurface->rcDst.left   = TPRenderParams.pTarget[0]->rcSrc.left;
-                    RenderPassData.pSrcSurface->rcDst.bottom = TPRenderParams.pTarget[0]->rcSrc.bottom;
-                    RenderPassData.pSrcSurface->rcDst.right  = TPRenderParams.pTarget[0]->rcSrc.right;
+                    RenderPassData.pSrcSurface->rcDst.top    = pRenderParams->pTarget[0]->rcSrc.top;
+                    RenderPassData.pSrcSurface->rcDst.left   = pRenderParams->pTarget[0]->rcSrc.left;
+                    RenderPassData.pSrcSurface->rcDst.bottom = pRenderParams->pTarget[0]->rcSrc.bottom;
+                    RenderPassData.pSrcSurface->rcDst.right  = pRenderParams->pTarget[0]->rcSrc.right;
                 }
-                RenderSingleStream(&TPRenderParams, &RenderPassData);
+
+                RenderSingleStream(pRenderParams, &RenderPassData);
 
                 if (!RenderPassData.bCompNeeded &&
-                    TPRenderParams.pTarget[0] &&
-                    TPRenderParams.pTarget[0]->bFastColorFill)
+                    pRenderParams->pTarget[0] &&
+                    pRenderParams->pTarget[0]->bFastColorFill)
                 {
                     // with fast color fill enabled, we seperate target surface into two parts:
                     // (1) upper rectangle rendered by vebox
                     // (2) bottom rectangle with back ground color fill by composition
                     pRenderParams->uSrcCount = 0; // set to zero for color fill
-                    TPRenderParams.pTarget[0]->rcDst.top = TPRenderParams.pSrc[0]->rcDst.bottom;
+                    pRenderParams->pTarget[0]->rcDst.top = pRenderParams->pSrc[0]->rcDst.bottom;
                     RenderPassData.bCompNeeded = true;
                     VPHAL_RENDER_ASSERTMESSAGE("Critical: enter fast color fill");
                 }
-
-                if (RenderPassData.bCompNeeded)
+                if (RenderPassData.bCompNeeded &&
+                    (uiIndex_in == pRenderParams->uSrcCount-1 || // compatible with N:1 case, only render at the last input.
+                     pRenderParams->uSrcCount == 0))             // fast color fill
                 {
-                    VPHAL_RENDER_CHK_STATUS(RenderComposite(&TPRenderParams, &RenderPassData));
+                    VPHAL_RENDER_CHK_STATUS(RenderComposite(pRenderParams, &RenderPassData));
+                }
+                else if (VpHal_RndrIsHdrPathNeeded(this, pRenderParams, &RenderPassData) && !pHdrState->bBypassHdrKernelPath)
+                {
+                    VPHAL_RENDER_CHK_STATUS(VpHal_RndrRenderHDR(this, pRenderParams, &RenderPassData));
                 }
-
-                // Report Render modes
-                UpdateReport(pRenderParams, &RenderPassData);
             }
+            // restore render pointer and count.
+            pRenderParams->pTarget[0]            = StoreRenderParams.pTarget[0];
+            pRenderParams->pTarget[0]->b16UsrPtr = StoreRenderParams.pTarget[0]->b16UsrPtr;
+            pRenderParams->uDstCount             = StoreRenderParams.uDstCount;
         }
     }
 
+    // Report Render modes
+    UpdateReport(pRenderParams, &RenderPassData);
+
     //------------------------------------------
     VPHAL_RNDR_DUMP_SURF_PTR_ARRAY(
         this, pRenderParams->pTarget, VPHAL_MAX_TARGETS,
@@ -827,6 +842,16 @@ MOS_STATUS VphalRenderer::RenderSingleStream(
             pRenderParams,
             pRenderPassData));
 
+        if (pRenderPassData->bSFCScalingOnly)
+        {
+            // set the output surface which from the Vebox+SFC as input surface, and let comp to do composite.
+            VPHAL_RENDER_CHK_NULL(pRenderPassData->pOutSurface);
+            pRenderPassData->bCompNeeded = true;
+            pRenderPassData->bSFCScalingOnly = false;
+            pRenderPassData->pSrcSurface = pRenderPassData->pOutSurface;
+            pRenderPassData->pSrcSurface->SurfType = SURF_IN_PRIMARY;
+        }
+
         if (pRenderPassData->bOutputGenerated)
         {
             pRenderPassData->pSrcSurface = pRenderPassData->pOutSurface;
@@ -846,10 +871,15 @@ MOS_STATUS VphalRenderer::RenderSingleStream(
             this, pRenderPassData->uiSrcIndex, VPHAL_DBG_DUMP_TYPE_POST_DNDI, pRenderPassData->pSrcSurface);
 
         // We'll continue even if Advanced render fails
-        if ((eStatus == MOS_STATUS_SUCCESS) && (pRenderPassData->bCompNeeded))
+        if ((eStatus == MOS_STATUS_SUCCESS) && (pRenderPassData->bCompNeeded || pRenderPassData->bHdrNeeded))
         {
             pRenderParams->pSrc[pRenderPassData->uiSrcIndex] = pRenderPassData->pSrcSurface;
         }
+
+        if (pRenderPassData->bHdrNeeded && !pHdrState->bBypassHdrKernelPath)
+        {
+            pRenderPassData->bCompNeeded = false;
+        }
     }
 
 finish:
@@ -909,22 +939,17 @@ MOS_STATUS VphalRenderer::RenderComposite(
         pRenderParams->uSrcCount, VPHAL_DBG_DUMP_TYPE_PRE_COMP);
     //------------------------------------------
 
-    if (pRenderParams->bUserPrt_16Align[0])
+    if (pRenderPassData->pSrcSurface &&
+        (pRenderPassData->pSrcSurface->b16UsrPtr ||
+        pRenderParams->pTarget[0]->b16UsrPtr) &&
+        (VpHal_RndrIs16Align(&Align16State, pRenderParams)))
     {
-        if (VpHal_RndrIs16Align(pRenderParams))
-        {
-            eStatus = Align16State.pfnRender(&Align16State, pRenderParams);
-        }
-        else
-        {
-            // if doesn't support format under UserPtr mode, return error
-            VPHAL_RENDER_ASSERTMESSAGE("Invalid UserPtr parameters!");
-            eStatus = MOS_STATUS_INVALID_PARAMETER;
-            goto finish;
-        }
+        // process 16aligned usrptr mode.
+        VPHAL_RENDER_CHK_STATUS(Align16State.pfnRender(&Align16State, pRenderParams));
     }
     else
     {
+        // fallback to legacy path
         VPHAL_RENDER_CHK_STATUS(pRender[VPHAL_RENDER_ID_COMPOSITE]->Render(pRenderParams, nullptr));
     }
 
@@ -991,7 +1016,7 @@ bool VphalRenderer::IsFormatSupported(
     VPHAL_RENDER_ASSERT(pcRenderParams);
 
     // Protection mechanism
-    // P010 output support from KBL+
+    // P010 output support from SKL+
     if (m_pSkuTable)
     {
         if (pcRenderParams->pTarget[0])
@@ -1069,7 +1094,7 @@ MOS_STATUS VphalRenderer::Render(
         goto finish;
     }
 
-    // Protection mechanism, Only KBL+ support P010 output.
+    // Protection mechanism, Only SKL+ support P010 output.
     if (IsFormatSupported(pcRenderParams) == false)
     {
         VPHAL_RENDER_ASSERTMESSAGE("Invalid Render Target Output Format.");
@@ -1138,10 +1163,16 @@ MOS_STATUS VphalRenderer::Render(
             pSrcRight,
             &uiRenderPasses));
 
+    //Update GpuContext
+    if (MEDIA_IS_SKU(m_pSkuTable, FtrCCSNode))
+    {
+        MOS_GPU_CONTEXT currentGpuContext = m_pOsInterface->pfnGetGpuContext(m_pOsInterface);
+        UpdateRenderGpuContext(currentGpuContext);
+    }
     // align rectangle and source surface
     for (uiDst = 0; uiDst < RenderParams.uDstCount; uiDst++)
     {
-        VPHAL_RENDER_CHK_STATUS(VpHal_RndrRectSurfaceAlignment(RenderParams.pTarget[uiDst]));
+        VPHAL_RENDER_CHK_STATUS(VpHal_RndrRectSurfaceAlignment(RenderParams.pTarget[uiDst], RenderParams.pTarget[uiDst]->Format));
     }
 
     for (uiCurrentRenderPass = 0;
@@ -1173,12 +1204,98 @@ MOS_STATUS VphalRenderer::Render(
 
         VPHAL_RENDER_CHK_STATUS(RenderPass(&RenderParams));
     }
+
+#if defined(LINUX)
+    if (m_reporting)
+    {
+        WriteUserFeature(__VPHAL_VEBOX_OUTPUTPIPE_MODE_ID, m_reporting->OutputPipeMode);
+        WriteUserFeature(__VPHAL_VEBOX_FEATURE_INUSE_ID, m_reporting->VEFeatureInUse);
+    }
+#endif
+
 finish:
     uiFrameCounter++;
     return eStatus;
 }
 
 //!
+//! \brief    Update Render Gpu Context
+//! \details  Update Render Gpu Context
+//! \param    [in] renderGpuContext
+//! \return   MOS_STATUS
+//!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+//!
+MOS_STATUS VphalRenderer::UpdateRenderGpuContext(MOS_GPU_CONTEXT currentGpuContext)
+{
+    MOS_STATUS              eStatus = MOS_STATUS_SUCCESS;
+    MOS_GPU_CONTEXT         renderGpuContext;
+    MOS_GPU_NODE            renderGpuNode;
+    MOS_GPUCTX_CREATOPTIONS createOption;
+    PVPHAL_VEBOX_STATE      pVeboxState = nullptr;
+    int                     i           = 0;
+
+    if (m_pOsInterface->osCpInterface->IsCpEnabled() &&
+        (m_pOsInterface->osCpInterface->IsHMEnabled() || m_pOsInterface->osCpInterface->IsSMEnabled()))
+    {
+        if (currentGpuContext == MOS_GPU_CONTEXT_COMPUTE ||
+            currentGpuContext == MOS_GPU_CONTEXT_COMPUTE_RA)  // CCS
+        {
+            renderGpuContext = MOS_GPU_CONTEXT_COMPUTE_RA;
+            renderGpuNode    = MOS_GPU_NODE_COMPUTE;
+        }
+        else  // RCS
+        {
+            renderGpuContext = MOS_GPU_CONTEXT_RENDER_RA;
+            renderGpuNode    = MOS_GPU_NODE_3D;
+        }
+        createOption.RAMode = 1;
+    }
+    else
+    {
+        if (currentGpuContext == MOS_GPU_CONTEXT_COMPUTE ||
+            currentGpuContext == MOS_GPU_CONTEXT_COMPUTE_RA)  // CCS
+        {
+            renderGpuContext = MOS_GPU_CONTEXT_COMPUTE;
+            renderGpuNode    = MOS_GPU_NODE_COMPUTE;
+        }
+        else  // RCS
+        {
+            renderGpuContext = MOS_GPU_CONTEXT_RENDER;
+            renderGpuNode    = MOS_GPU_NODE_3D;
+        }
+        createOption.RAMode = 0;
+    }
+
+    // no gpucontext will be created if the gpu context has been created before.
+    VPHAL_PUBLIC_CHK_STATUS(m_pOsInterface->pfnCreateGpuContext(
+        m_pOsInterface,
+        renderGpuContext,
+        renderGpuNode,
+        &createOption));
+
+    VPHAL_PUBLIC_CHK_STATUS(m_pOsInterface->pfnSetGpuContext(
+        m_pOsInterface,
+        renderGpuContext));
+
+    // Register Render GPU context with the event
+    VPHAL_PUBLIC_CHK_STATUS(m_pOsInterface->pfnRegisterBBCompleteNotifyEvent(
+        m_pOsInterface,
+        renderGpuContext));
+
+    //update sub render status one by one
+    for (i = 0; i < VPHAL_RENDER_ID_COUNT - 1; i++)
+    {  // VPHAL_RENDER_ID_COMPOSITE is not inherited from vphal_vebox_state, skip it.
+        pVeboxState = (PVPHAL_VEBOX_STATE)(pRender[i]);
+        if (pVeboxState != nullptr)
+        {
+            pVeboxState->UpdateRenderGpuContext(renderGpuContext);
+        }
+    }
+finish:
+    VPHAL_RENDER_NORMALMESSAGE("gpucontext switch from %d to %d", currentGpuContext, renderGpuContext);
+    return eStatus;
+}
+    //!
 //! \brief    Release intermediate surfaces
 //! \details  Release intermediate surfaces created for main render function
 //! \return   MOS_STATUS
@@ -1220,17 +1337,23 @@ MOS_STATUS VphalRenderer::Initialize(
     Kdll_KernelCache                    *pKernelCache;
     Kdll_CacheEntry                     *pCacheEntryTable;
 
+    pKernelBin      = nullptr;
+    pFcPatchBin     = nullptr;
+    eStatus         = MOS_STATUS_UNKNOWN;
+    pOsInterface    = m_pOsInterface;
+    pRenderHal      = m_pRenderHal;
+    iResult         = 0;
+    pKernelBin      = nullptr;
+    pFcPatchBin     = nullptr;
+
+    MOS_ZeroMemory(&MhwKernelParam, sizeof(MHW_KERNEL_PARAM));
+
     //---------------------------------------
     VPHAL_RENDER_CHK_NULL(pSettings);
     VPHAL_RENDER_CHK_NULL(m_pOsInterface);
     VPHAL_RENDER_CHK_NULL(m_pRenderHal);
     //---------------------------------------
 
-    eStatus         = MOS_STATUS_UNKNOWN;
-    pOsInterface    = m_pOsInterface;
-    pRenderHal      = m_pRenderHal;
-    pFcPatchBin     = nullptr;
-
     Align16State.pPerfData   = &PerfData;
     Fast1toNState.pPerfData  = &PerfData;
     // Current KDLL expects a writable memory for kernel binary. For that reason,
@@ -1324,7 +1447,12 @@ MOS_STATUS VphalRenderer::Initialize(
            pSettings,
            pKernelDllState))
 
-    AllocateDebugDumper();
+    eStatus = AllocateDebugDumper();
+    if (eStatus != MOS_STATUS_SUCCESS)
+    {
+        VPHAL_RENDER_ASSERTMESSAGE("Debug dumper allocate failed!");
+        goto finish;
+    }
 
     if (MEDIA_IS_SKU(m_pSkuTable, FtrVpDisableFor4K))
     {
@@ -1335,9 +1463,30 @@ MOS_STATUS VphalRenderer::Initialize(
         bSkuDisableVpFor4K = false;
     }
 
+    // Initialize Hdr renderer
+    if (MEDIA_IS_SKU(m_pSkuTable, FtrHDR) && pHdrState)
+    {
+        VPHAL_RENDER_CHK_STATUS(pHdrState->pfnInitialize(
+            pHdrState,
+            pSettings,
+            pKernelDllState));
+    }
+
     eStatus = MOS_STATUS_SUCCESS;
 
 finish:
+    if (eStatus != MOS_STATUS_SUCCESS)
+    {
+        if (pKernelBin)
+        {
+            MOS_SafeFreeMemory(pKernelBin);
+        }
+
+        if (pFcPatchBin)
+        {
+            MOS_SafeFreeMemory(pFcPatchBin);
+        }
+    }
     return eStatus;
 }
 
@@ -1350,18 +1499,6 @@ VphalRenderer::~VphalRenderer()
 {
     VPHAL_RENDER_CHK_NULL_NO_STATUS(m_pOsInterface);
 
-#if defined(LINUX)
-    MOS_USER_FEATURE_VALUE_WRITE_DATA   userFeatureWriteData;
-    MOS_ZeroMemory(&userFeatureWriteData, sizeof(userFeatureWriteData));
-    userFeatureWriteData.Value.i32Data  = m_reporting->OutputPipeMode;
-    userFeatureWriteData.ValueID        = __VPHAL_VEBOX_OUTPUTPIPE_MODE_ID;
-    MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
-    MOS_ZeroMemory(&userFeatureWriteData, sizeof(userFeatureWriteData));
-    userFeatureWriteData.Value.bData  = m_reporting->VEFeatureInUse;
-    userFeatureWriteData.ValueID        = __VPHAL_VEBOX_FEATURE_INUSE_ID;
-    MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
-#endif
-
     FreeIntermediateSurfaces();
 
     MOS_Delete(m_reporting);
@@ -1394,6 +1531,13 @@ VphalRenderer::~VphalRenderer()
         Fast1toNState.pfnDestroy(&Fast1toNState);
     }
 
+    // Destroy resources allocated for Hdr
+    if (MEDIA_IS_SKU(m_pSkuTable, FtrHDR) && pHdrState && pHdrState->pfnDestroy)
+    {
+        pHdrState->pfnDestroy(pHdrState);
+        MOS_Delete(pHdrState);
+    }
+
     // Destroy surface dumper
     VPHAL_DBG_SURF_DUMP_DESTORY(m_surfaceDumper);
 
@@ -1545,19 +1689,8 @@ MOS_STATUS VpHal_RndrSetYUVComponents(
 VphalRenderer::VphalRenderer(
     PRENDERHAL_INTERFACE                pRenderHal,
     MOS_STATUS                          *pStatus) :
-    m_pRenderHal(pRenderHal),
-    m_pOsInterface(pRenderHal->pOsInterface),
-    m_pSkuTable(nullptr),
-    m_modifyKdllFunctionPointers(nullptr),
     Align16State(),
     Fast1toNState(),
-    uiSsdControl(0),
-    bDpRotationUsed(false),
-    bSkuDisableVpFor4K(false),
-    bSkuDisableLaceFor4K(false),
-    bSkuDisableDNFor4K(false),
-    PerfData(),
-    m_reporting(nullptr),
     VeboxExecState(),
     pRender(),
     pPrimaryFwdRef(),
@@ -1574,12 +1707,27 @@ VphalRenderer::VphalRenderer(
     m_surfaceDumper(nullptr),
     m_parameterDumper(nullptr),
 #endif
-    StatusTable(),
-    maxSrcRect()
+    m_statusTable(nullptr),
+    maxSrcRect(),
+    pHdrState(nullptr),
+    m_pRenderHal(pRenderHal),
+    m_pOsInterface(pRenderHal ? pRenderHal->pOsInterface : nullptr),
+    m_pSkuTable(nullptr),
+    m_modifyKdllFunctionPointers(nullptr),
+    uiSsdControl(0),
+    bDpRotationUsed(false),
+    bSkuDisableVpFor4K(false),
+    bSkuDisableLaceFor4K(false),
+    bSkuDisableDNFor4K(false),
+    PerfData(),
+    m_reporting(nullptr)
 {
     MOS_STATUS                          eStatus;
     MOS_USER_FEATURE_VALUE_DATA         UserFeatureData;
 
+    VPHAL_RENDER_CHK_NULL(m_pRenderHal);
+    VPHAL_RENDER_CHK_NULL(m_pOsInterface);
+
     MOS_ZeroMemory(&pRender, sizeof(pRender));
 
     // Read Slice Shutdown (SSD Control) User Feature Key once during initialization
@@ -1599,7 +1747,11 @@ VphalRenderer::VphalRenderer(
     // Get SKU table
     m_pSkuTable = m_pOsInterface->pfnGetSkuTable(m_pOsInterface);
 
-    *pStatus = eStatus;
+finish:
+    if (pStatus)
+    {
+        *pStatus = eStatus;
+    }
 }
 
 //!
@@ -1904,18 +2056,170 @@ finish:
     return;
 }
 
-void VphalRenderer::AllocateDebugDumper()
+MOS_STATUS VphalRenderer::AllocateDebugDumper()
 {
     PRENDERHAL_INTERFACE pRenderHal = m_pRenderHal;
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
     // Allocate feature report
     m_reporting = MOS_New(VphalFeatureReport);
+    if (m_reporting == nullptr)
+    {
+        VPHAL_RENDER_ASSERTMESSAGE("Invalid null pointer!");
+        eStatus = MOS_STATUS_NULL_POINTER;
+        goto finish;
+    }
+
+#if (_DEBUG || _RELEASE_INTERNAL)
 
     // Initialize Surface Dumper
-    VPHAL_DBG_SURF_DUMP_CREATE();
+    VPHAL_DBG_SURF_DUMP_CREATE()
+    if (m_surfaceDumper == nullptr)
+    {
+        VPHAL_RENDER_ASSERTMESSAGE("Invalid null pointer!");
+        eStatus = MOS_STATUS_NULL_POINTER;
+        goto finish;
+    }
 
     // Initialize State Dumper
-    VPHAL_DBG_STATE_DUMPPER_CREATE();
+    VPHAL_DBG_STATE_DUMPPER_CREATE()
+    if (pRenderHal->pStateDumper == nullptr)
+    {
+        VPHAL_RENDER_ASSERTMESSAGE("Invalid null pointer!");
+        eStatus = MOS_STATUS_NULL_POINTER;
+        goto finish;
+    }
 
-    VPHAL_DBG_PARAMETERS_DUMPPER_CREATE();
+    VPHAL_DBG_PARAMETERS_DUMPPER_CREATE()
+    if (m_parameterDumper == nullptr)
+    {
+        VPHAL_RENDER_ASSERTMESSAGE("Invalid null pointer!");
+        eStatus = MOS_STATUS_NULL_POINTER;
+        goto finish;
+    }
+
+#endif
+
+finish:
+    if (eStatus != MOS_STATUS_SUCCESS)
+    {
+        if (m_reporting)
+        {
+            MOS_Delete(m_reporting);
+            m_reporting = nullptr;
+        }
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+
+        if (m_surfaceDumper)
+        {
+            VPHAL_DBG_SURF_DUMP_DESTORY(m_surfaceDumper)
+        }
+
+        if (pRenderHal->pStateDumper)
+        {
+            VPHAL_DBG_STATE_DUMPPER_DESTORY(pRenderHal->pStateDumper)
+        }
+#endif
+
+    }
+
+    return eStatus;
+}
+
+//!
+//! \brief    Get Hdr path needed flag
+//! \details  Get Hdr path needed flag
+//! \param    pRenderParams
+//!           [in] Pointer to VPHAL render parameter
+//! \param    pRenderPassData
+//!           [in,out] Pointer to the VPHAL render pass data
+//! \return   MOS_STATUS
+//!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+//!
+MOS_STATUS VphalRenderer::GetHdrPathNeededFlag(
+    PVPHAL_RENDER_PARAMS    pRenderParams,
+    RenderpassData          *pRenderPassData)
+{
+    MOS_STATUS              eStatus;
+    uint32_t                uiIndex;
+    PVPHAL_SURFACE          pSrcSurface;
+    PVPHAL_SURFACE          pTargetSurface;
+    bool                    bToneMapping;
+    bool                    bBt2020Output;
+    bool                    bMultiLayerBt2020;
+
+    //--------------------------------------------
+    VPHAL_RENDER_CHK_NULL(pRenderParams);
+    VPHAL_RENDER_CHK_NULL(pRenderPassData);
+    VPHAL_RENDER_CHK_NULL(pRenderParams->pTarget[0]);
+    //--------------------------------------------
+
+    eStatus                     = MOS_STATUS_SUCCESS;
+    uiIndex                     = 0;
+    pSrcSurface                 = nullptr;
+    pTargetSurface              = nullptr;
+    bToneMapping                = false;
+    bBt2020Output               = false;
+    bMultiLayerBt2020           = false;
+
+    // Loop through the sources
+    for (uiIndex = 0;
+        uiIndex < VPHAL_MAX_SOURCES && uiIndex < pRenderParams->uSrcCount;
+        uiIndex++)
+    {
+        pSrcSurface = pRenderParams->pSrc[uiIndex];
+        if (pSrcSurface == nullptr)
+        {
+            continue;
+        }
+        pTargetSurface = pRenderParams->pTarget[0];
+
+        // Need to use HDR to process BT601/BT709->BT2020
+        if (IS_COLOR_SPACE_BT2020(pRenderParams->pTarget[0]->ColorSpace) &&
+            !IS_COLOR_SPACE_BT2020(pSrcSurface->ColorSpace))
+        {
+            bBt2020Output = true;
+        }
+
+        if ((pSrcSurface->pHDRParams && (pSrcSurface->pHDRParams->EOTF != VPHAL_HDR_EOTF_TRADITIONAL_GAMMA_SDR)) ||
+            (pTargetSurface->pHDRParams && (pTargetSurface->pHDRParams->EOTF != VPHAL_HDR_EOTF_TRADITIONAL_GAMMA_SDR)))
+        {
+            bToneMapping = true;
+        }
+
+        if (IS_COLOR_SPACE_BT2020(pSrcSurface->ColorSpace) && pRenderParams->uSrcCount > 1)
+        {
+            bMultiLayerBt2020 = true;
+        }
+    }
+
+    pRenderPassData->bHdrNeeded = bBt2020Output || bToneMapping || bMultiLayerBt2020;
+
+    // Error handling for illegal Hdr cases on unsupported m_Platform
+    if ((pRenderPassData->bHdrNeeded) && (!MEDIA_IS_SKU(m_pSkuTable, FtrHDR)))
+    {
+        eStatus = MOS_STATUS_SUCCESS;
+        VPHAL_RENDER_ASSERTMESSAGE("Illegal Hdr cases on unsupported m_Platform, turn off HDR.");
+        pRenderPassData->bHdrNeeded = false;
+    }
+
+    if (pRenderPassData->bHdrNeeded)
+    {
+        pRenderPassData->bCompNeeded = false;
+    }
+
+    if (!pRenderPassData->bHdrNeeded &&
+        pRenderParams->pSrc[0] &&
+        pRenderParams->pTarget[0] &&
+        IS_COLOR_SPACE_BT2020(pRenderParams->pSrc[0]->ColorSpace) &&
+        !IS_COLOR_SPACE_BT2020(pRenderParams->pTarget[0]->ColorSpace) &&
+        MEDIA_IS_SKU(m_pSkuTable, FtrDisableVEBoxFeatures))
+    {
+        eStatus = MOS_STATUS_INVALID_PARAMETER;
+        VPHAL_RENDER_ASSERTMESSAGE("Invalid Params for This Platform.");
+    }
+
+finish:
+    return eStatus;
 }
