@@ -150,6 +150,7 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
                 if (eStatus != MOS_STATUS_SUCCESS)
                 {
                     CODECHAL_ENCODE_ASSERTMESSAGE("Failed to copy memory.");
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
                     return eStatus;
                 }
             }
@@ -165,6 +166,7 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
             if (eStatus != MOS_STATUS_SUCCESS)
             {
                 CODECHAL_ENCODE_ASSERTMESSAGE("Failed to copy memory.");
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
                 return eStatus;
             }
 
@@ -184,7 +186,12 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
             }
         }
 
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxJpegFqmCmd(&cmdBuffer, &fqmParams, numQuantTables));
+        eStatus = (MOS_STATUS) m_mfxInterface->AddMfxJpegFqmCmd(&cmdBuffer, &fqmParams, numQuantTables);
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
 
         // set MFC_JPEG_HUFF_TABLE - Convert encoded huffman table to actual table for HW
         // We need a different params struct for JPEG Encode Huffman table because JPEG decode huffman table has Bits and codes,
@@ -195,34 +202,59 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
             CodechalEncodeJpegHuffTable huffmanTable;// intermediate table for each AC/DC component which will be copied to huffTableParams
             MOS_ZeroMemory(&huffmanTable, sizeof(huffmanTable));
 
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(ConvertHuffDataToTable(m_jpegHuffmanTable->m_huffmanData[i], &huffmanTable));
+            eStatus = (MOS_STATUS) ConvertHuffDataToTable(m_jpegHuffmanTable->m_huffmanData[i], &huffmanTable);
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+            }
 
             huffTableParams[m_jpegHuffmanTable->m_huffmanData[i].m_tableID].HuffTableID = m_jpegHuffmanTable->m_huffmanData[i].m_tableID;
 
             if (m_jpegHuffmanTable->m_huffmanData[i].m_tableClass == 0) // DC table
             {
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(MOS_SecureMemcpy(
+                eStatus = (MOS_STATUS) MOS_SecureMemcpy(
                     huffTableParams[m_jpegHuffmanTable->m_huffmanData[i].m_tableID].pDCCodeValues,
                     JPEG_NUM_HUFF_TABLE_DC_HUFFVAL * sizeof(uint16_t),
                     &huffmanTable.m_huffCode,
-                    JPEG_NUM_HUFF_TABLE_DC_HUFFVAL * sizeof(uint16_t)));
+                    JPEG_NUM_HUFF_TABLE_DC_HUFFVAL * sizeof(uint16_t));
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
 
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(MOS_SecureMemcpy(huffTableParams[m_jpegHuffmanTable->m_huffmanData[i].m_tableID].pDCCodeLength,
+                eStatus = (MOS_STATUS) MOS_SecureMemcpy(huffTableParams[m_jpegHuffmanTable->m_huffmanData[i].m_tableID].pDCCodeLength,
                     JPEG_NUM_HUFF_TABLE_DC_HUFFVAL * sizeof(uint8_t),
                     &huffmanTable.m_huffSize,
-                    JPEG_NUM_HUFF_TABLE_DC_HUFFVAL * sizeof(uint8_t)));
+                    JPEG_NUM_HUFF_TABLE_DC_HUFFVAL * sizeof(uint8_t));
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
             }
             else // AC Table
             {
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(MOS_SecureMemcpy(huffTableParams[m_jpegHuffmanTable->m_huffmanData[i].m_tableID].pACCodeValues,
+                eStatus = (MOS_STATUS) MOS_SecureMemcpy(huffTableParams[m_jpegHuffmanTable->m_huffmanData[i].m_tableID].pACCodeValues,
                     JPEG_NUM_HUFF_TABLE_AC_HUFFVAL * sizeof(uint16_t),
                     &huffmanTable.m_huffCode,
-                    JPEG_NUM_HUFF_TABLE_AC_HUFFVAL * sizeof(uint16_t)));
+                    JPEG_NUM_HUFF_TABLE_AC_HUFFVAL * sizeof(uint16_t));
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
 
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(MOS_SecureMemcpy(huffTableParams[m_jpegHuffmanTable->m_huffmanData[i].m_tableID].pACCodeLength,
+                eStatus = (MOS_STATUS) MOS_SecureMemcpy(huffTableParams[m_jpegHuffmanTable->m_huffmanData[i].m_tableID].pACCodeLength,
                     JPEG_NUM_HUFF_TABLE_AC_HUFFVAL * sizeof(uint8_t),
                     &huffmanTable.m_huffSize,
-                    JPEG_NUM_HUFF_TABLE_AC_HUFFVAL * sizeof(uint8_t)));
+                    JPEG_NUM_HUFF_TABLE_AC_HUFFVAL * sizeof(uint8_t));
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
             }
         }
 
@@ -247,6 +279,7 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
                 if (eStatus != MOS_STATUS_SUCCESS)
                 {
                     CODECHAL_ENCODE_ASSERTMESSAGE("Failed to copy memory.");
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
                     return eStatus;
                 }
 
@@ -257,6 +290,7 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
                 if (eStatus != MOS_STATUS_SUCCESS)
                 {
                     CODECHAL_ENCODE_ASSERTMESSAGE("Failed to copy memory.");
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
                     return eStatus;
                 }
             }
@@ -267,10 +301,20 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
         {
             if (repeatHuffTable)
             {
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfcJpegHuffTableStateCmd(&cmdBuffer, &huffTableParams[i]));
+                eStatus = (MOS_STATUS) (m_mfxInterface->AddMfcJpegHuffTableStateCmd(&cmdBuffer, &huffTableParams[i]));
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
             }
 
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfcJpegHuffTableStateCmd(&cmdBuffer, &huffTableParams[i]));
+            eStatus = (MOS_STATUS) m_mfxInterface->AddMfcJpegHuffTableStateCmd(&cmdBuffer, &huffTableParams[i]);
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+            }
         }
 
         // set MFC_JPEG_SCAN_OBJECT
@@ -281,7 +325,12 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
         scanObjectParams.dwPicHeight = m_jpegPicParams->m_picHeight;
         scanObjectParams.pJpegEncodeScanParams = m_jpegScanParams;
 
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfcJpegScanObjCmd(&cmdBuffer, &scanObjectParams));
+        eStatus = (MOS_STATUS) m_mfxInterface->AddMfcJpegScanObjCmd(&cmdBuffer, &scanObjectParams);
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
 
         // set MFC_JPEG_PAK_INSERT_OBJECT
         MHW_VDBOX_PAK_INSERT_PARAMS pakInsertObjectParams;
@@ -289,17 +338,38 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
 
         // The largest component written through the MFC_JPEG_PAK_INSERT_OBJECT command is Huffman table
         pakInsertObjectParams.pBsBuffer = (BSBuffer *)MOS_AllocAndZeroMemory(sizeof(CodechalEncodeJpegFrameHeader));
-        CODECHAL_ENCODE_CHK_NULL_RETURN(pakInsertObjectParams.pBsBuffer);
+        if (pakInsertObjectParams.pBsBuffer == nullptr)
+        {
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_NULL_RETURN(nullptr);
+        }
 
-        // Add SOI (0xFFD8) (only if it was sent by the application)
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(PackSOI(pakInsertObjectParams.pBsBuffer));
-        pakInsertObjectParams.dwOffset = 0;
-        pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
-        pakInsertObjectParams.bLastHeader = false;
-        pakInsertObjectParams.bEndOfSlice = false;
-        pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr, &pakInsertObjectParams));
-        MOS_FreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+        if(!m_fullHeaderInAppData)
+        {
+            // Add SOI (0xFFD8) (only if it was sent by the application)
+            eStatus = (MOS_STATUS)PackSOI(pakInsertObjectParams.pBsBuffer);
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+            }
+            pakInsertObjectParams.dwOffset = 0;
+            pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
+            pakInsertObjectParams.bLastHeader = false;
+            pakInsertObjectParams.bEndOfSlice = false;
+            pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
+            eStatus = (MOS_STATUS) m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr, &pakInsertObjectParams);
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+            }
+            MOS_FreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+        }
 
         // Add Application data if it was sent by application
         if (m_applicationData != nullptr)
@@ -320,7 +390,13 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
             }
 
             appDataChunk = (uint8_t*)MOS_AllocAndZeroMemory(appDataChunkSize);
-            CODECHAL_ENCODE_CHK_NULL_RETURN(appDataChunk);
+            if (appDataChunk == nullptr)
+            {
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                CODECHAL_ENCODE_CHK_NULL_RETURN(nullptr);
+            }
 
             for (uint32_t i = 0; i < numAppDataCmdsNeeded; i++)
             {
@@ -329,14 +405,38 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
                 MOS_SecureMemcpy(appDataChunk, appDataChunkSize,
                     copyAddress, appDataChunkSize);
 
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(PackApplicationData(pakInsertObjectParams.pBsBuffer, appDataChunk, appDataChunkSize));
+                eStatus = (MOS_STATUS)PackApplicationData(pakInsertObjectParams.pBsBuffer, appDataChunk, appDataChunkSize);
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    MOS_SafeFreeMemory(appDataChunk);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
                 pakInsertObjectParams.dwOffset = 0;
                 pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
-                pakInsertObjectParams.bLastHeader = false;
-                pakInsertObjectParams.bEndOfSlice = false;
+                if((appDataCmdSizeResidue == 0) && m_fullHeaderInAppData)
+                {
+                    pakInsertObjectParams.bLastHeader = true;
+                    pakInsertObjectParams.bEndOfSlice = true;
+                }
+                else
+                {
+                    pakInsertObjectParams.bLastHeader = false;
+                    pakInsertObjectParams.bEndOfSlice = false;
+                }
                 pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
-                    &pakInsertObjectParams));
+                eStatus = (MOS_STATUS)m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
+                    &pakInsertObjectParams);
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    MOS_SafeFreeMemory(appDataChunk);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
             }
 
             if (appDataCmdSizeResidue != 0)
@@ -348,29 +448,69 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
                     lastAddress,
                     appDataChunkSize);
 
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(PackApplicationData(pakInsertObjectParams.pBsBuffer, appDataChunk, appDataCmdSizeResidue));
+                eStatus = (MOS_STATUS)PackApplicationData(pakInsertObjectParams.pBsBuffer, appDataChunk, appDataCmdSizeResidue);
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    MOS_SafeFreeMemory(appDataChunk);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
                 pakInsertObjectParams.dwOffset = 0;
                 pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
-                pakInsertObjectParams.bLastHeader = false;
-                pakInsertObjectParams.bEndOfSlice = false;
+                if(m_fullHeaderInAppData)
+                {
+                    pakInsertObjectParams.bLastHeader = true;
+                    pakInsertObjectParams.bEndOfSlice = true;
+                }
+                else
+                {
+                    pakInsertObjectParams.bLastHeader = false;
+                    pakInsertObjectParams.bEndOfSlice = false;
+                }
                 pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
-                    &pakInsertObjectParams));
+                eStatus = (MOS_STATUS)m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
+                    &pakInsertObjectParams);
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    MOS_SafeFreeMemory(appDataChunk);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
             }
 
             MOS_FreeMemory(appDataChunk);
         }
 
+        if(!m_fullHeaderInAppData)
+        {
         // Add Quant Table for Y
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(PackQuantTable(pakInsertObjectParams.pBsBuffer, jpegComponentY));
+        eStatus = (MOS_STATUS)PackQuantTable(pakInsertObjectParams.pBsBuffer, jpegComponentY);
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
 
         pakInsertObjectParams.dwOffset = 0;
         pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
         pakInsertObjectParams.bLastHeader = false;
         pakInsertObjectParams.bEndOfSlice = false;
         pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
-            &pakInsertObjectParams));
+        eStatus = (MOS_STATUS)m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
+            &pakInsertObjectParams);
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
         MOS_FreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
 
         if (!useSingleDefaultQuantTable)
@@ -379,94 +519,198 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
             if (m_jpegPicParams->m_inputSurfaceFormat != codechalJpegY8)
             {
                 // Add quant table for U
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(PackQuantTable(pakInsertObjectParams.pBsBuffer, jpegComponentU));
+                eStatus = (MOS_STATUS)PackQuantTable(pakInsertObjectParams.pBsBuffer, jpegComponentU);
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
                 pakInsertObjectParams.dwOffset = 0;
                 pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
                 pakInsertObjectParams.bLastHeader = false;
                 pakInsertObjectParams.bEndOfSlice = false;
                 pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
-                    &pakInsertObjectParams));
+                eStatus = (MOS_STATUS)m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
+                    &pakInsertObjectParams);
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
                 MOS_FreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
 
                 // Add quant table for V
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(PackQuantTable(pakInsertObjectParams.pBsBuffer, jpegComponentV));
+                eStatus = (MOS_STATUS)PackQuantTable(pakInsertObjectParams.pBsBuffer, jpegComponentV);
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
                 pakInsertObjectParams.dwOffset = 0;
                 pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
                 pakInsertObjectParams.bLastHeader = false;
                 pakInsertObjectParams.bEndOfSlice = false;
                 pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-                CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
-                    &pakInsertObjectParams));
+                eStatus = (MOS_STATUS)m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
+                    &pakInsertObjectParams);
+                if (eStatus != MOS_STATUS_SUCCESS)
+                {
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                    MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                    MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                    CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+                }
                 MOS_FreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
             }
         }
 
         // Add Frame Header
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(PackFrameHeader(pakInsertObjectParams.pBsBuffer, useSingleDefaultQuantTable));
+        eStatus = (MOS_STATUS)PackFrameHeader(pakInsertObjectParams.pBsBuffer, useSingleDefaultQuantTable);
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
         pakInsertObjectParams.dwOffset = 0;
         pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
         pakInsertObjectParams.bLastHeader = false;
         pakInsertObjectParams.bEndOfSlice = false;
         pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
-            &pakInsertObjectParams));
+        eStatus = (MOS_STATUS)m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
+            &pakInsertObjectParams);
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
         MOS_FreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
 
         // Add Huffman Table for Y - DC table, Y- AC table, U/V - DC table, U/V - AC table
         for (uint32_t i = 0; i < m_encodeParams.dwNumHuffBuffers; i++)
         {
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(PackHuffmanTable(pakInsertObjectParams.pBsBuffer, i));
+            eStatus = (MOS_STATUS)PackHuffmanTable(pakInsertObjectParams.pBsBuffer, i);
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+            }
             pakInsertObjectParams.dwOffset = 0;
             pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
             pakInsertObjectParams.bLastHeader = false;
             pakInsertObjectParams.bEndOfSlice = false;
             pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
-                &pakInsertObjectParams));
+            eStatus = (MOS_STATUS)m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
+                &pakInsertObjectParams);
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+            }
             MOS_FreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
         }
 
         // Restart Interval - Add only if the restart interval is not zero
         if (m_jpegScanParams->m_restartInterval != 0)
         {
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(PackRestartInterval(pakInsertObjectParams.pBsBuffer));
+            eStatus = (MOS_STATUS)PackRestartInterval(pakInsertObjectParams.pBsBuffer);
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+            }
             pakInsertObjectParams.dwOffset = 0;
             pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
             pakInsertObjectParams.bLastHeader = false;
             pakInsertObjectParams.bEndOfSlice = false;
             pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
-                &pakInsertObjectParams));
+            eStatus = (MOS_STATUS)m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
+                &pakInsertObjectParams);
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+                MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+                MOS_SafeFreeMemory(tempJpegQuantMatrix);
+                CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+            }
             MOS_FreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
         }
 
         // Add scan header
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(PackScanHeader(pakInsertObjectParams.pBsBuffer));
+        eStatus = (MOS_STATUS)PackScanHeader(pakInsertObjectParams.pBsBuffer);
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
         pakInsertObjectParams.dwOffset = 0;
         pakInsertObjectParams.dwBitSize = pakInsertObjectParams.pBsBuffer->BufferSize;
         pakInsertObjectParams.bLastHeader = true;
         pakInsertObjectParams.bEndOfSlice = true;
         pakInsertObjectParams.bResetBitstreamStartingPos = 1; // from discussion with HW Architect
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
-            &pakInsertObjectParams));
+        eStatus = (MOS_STATUS)m_mfxInterface->AddMfxPakInsertObject(&cmdBuffer, nullptr,
+            &pakInsertObjectParams);
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
+            MOS_SafeFreeMemory(pakInsertObjectParams.pBsBuffer);
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
         MOS_FreeMemory(pakInsertObjectParams.pBsBuffer->pBase);
-
+        }
         MOS_FreeMemory(pakInsertObjectParams.pBsBuffer);
     }
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(ReadMfcStatus(&cmdBuffer));
+    eStatus = ReadMfcStatus(&cmdBuffer);
+    if (eStatus != MOS_STATUS_SUCCESS)
+    {
+        MOS_SafeFreeMemory(tempJpegQuantMatrix);
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+    }
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(EndStatusReport(&cmdBuffer, CODECHAL_NUM_MEDIA_STATES));
+    eStatus = EndStatusReport(&cmdBuffer, CODECHAL_NUM_MEDIA_STATES);
+    if (eStatus != MOS_STATUS_SUCCESS)
+    {
+        MOS_SafeFreeMemory(tempJpegQuantMatrix);
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+    }
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferEnd(&cmdBuffer, nullptr));
+    eStatus = m_miInterface->AddMiBatchBufferEnd(&cmdBuffer, nullptr);
+    if (eStatus != MOS_STATUS_SUCCESS)
+    {
+        MOS_SafeFreeMemory(tempJpegQuantMatrix);
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+    }
 
     std::string pakPassName = "PAK_PASS" + std::to_string(static_cast<uint32_t>(m_currPass));
     CODECHAL_DEBUG_TOOL(
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_debugInterface->DumpCmdBuffer(
+        eStatus = m_debugInterface->DumpCmdBuffer(
             &cmdBuffer,
             CODECHAL_NUM_MEDIA_STATES,
-            pakPassName.data()));
+            pakPassName.data());
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(tempJpegQuantMatrix);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
 
     //CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHal_DbgReplaceAllCommands(
     //    m_debugInterface,
@@ -475,8 +719,18 @@ MOS_STATUS CodechalEncodeJpegStateG11::ExecuteSliceLevel()
 
         m_osInterface->pfnReturnCommandBuffer(m_osInterface, &cmdBuffer, 0);
 
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(SetAndPopulateVEHintParams(&cmdBuffer));
-    CODECHAL_ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_renderContextUsesNullHw));
+    eStatus = SetAndPopulateVEHintParams(&cmdBuffer);
+    if (eStatus != MOS_STATUS_SUCCESS)
+    {
+        MOS_SafeFreeMemory(tempJpegQuantMatrix);
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+    }
+    eStatus = m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_renderContextUsesNullHw);
+    if (eStatus != MOS_STATUS_SUCCESS)
+    {
+        MOS_SafeFreeMemory(tempJpegQuantMatrix);
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+    }
 
     if (tempJpegQuantMatrix != nullptr)
     {
@@ -519,7 +773,12 @@ MOS_STATUS CodechalEncodeJpegStateG11::Initialize(CodechalSetting  *settings)
     {
         m_sinlgePipeVeState = (PCODECHAL_ENCODE_SINGLEPIPE_VIRTUALENGINE_STATE)MOS_AllocAndZeroMemory(sizeof(CODECHAL_ENCODE_SINGLEPIPE_VIRTUALENGINE_STATE));
         CODECHAL_ENCODE_CHK_NULL_RETURN(m_sinlgePipeVeState);
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(CodecHalEncodeSinglePipeVE_InitInterface(m_hwInterface, m_sinlgePipeVeState));
+        eStatus = (MOS_STATUS) CodecHalEncodeSinglePipeVE_InitInterface(m_hwInterface, m_sinlgePipeVeState);
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            MOS_SafeFreeMemory(m_sinlgePipeVeState);
+            CODECHAL_ENCODE_CHK_STATUS_RETURN(eStatus);
+        }
     }
 
     return eStatus;
