@@ -34,10 +34,34 @@
 #include "media_ddi_decode_const_g11.h"
 #include "media_libva_vp.h"
 
-const VAImageFormat MediaLibvaCapsG11::m_G11ImageFormats[] =
-{    {VA_FOURCC_AYUV, VA_LSB_FIRST, 24, 0,0,0,0,0},
-     {VA_FOURCC_Y410, VA_LSB_FIRST, 24, 0,0,0,0,0},
-     {VA_FOURCC_Y416, VA_LSB_FIRST, 64, 0,0,0,0,0}
+const VAImageFormat m_supportedImageformatsG11[] =
+{   {VA_FOURCC_BGRA,   VA_LSB_FIRST,   32, 32, 0x0000ff00, 0x00ff0000, 0xff000000,  0x000000ff}, /* [31:0] B:G:R:A 8:8:8:8 little endian */
+    {VA_FOURCC_ARGB,   VA_LSB_FIRST,   32, 32, 0x00ff0000, 0x0000ff00, 0x000000ff,  0xff000000}, /* [31:0] A:R:G:B 8:8:8:8 little endian */
+    {VA_FOURCC_RGBA,   VA_LSB_FIRST,   32, 32, 0xff000000, 0x00ff0000, 0x0000ff00,  0x000000ff}, /* [31:0] R:G:B:A 8:8:8:8 little endian */
+    {VA_FOURCC_ABGR,   VA_LSB_FIRST,   32, 32, 0x000000ff, 0x0000ff00, 0x00ff0000,  0xff000000}, /* [31:0] A:B:G:R 8:8:8:8 little endian */
+    {VA_FOURCC_BGRX,   VA_LSB_FIRST,   32, 24, 0x0000ff00, 0x00ff0000, 0xff000000,  0}, /* [31:0] B:G:R:x 8:8:8:8 little endian */
+    {VA_FOURCC_XRGB,   VA_LSB_FIRST,   32, 24, 0x00ff0000, 0x0000ff00, 0x000000ff,  0}, /* [31:0] x:R:G:B 8:8:8:8 little endian */
+    {VA_FOURCC_RGBX,   VA_LSB_FIRST,   32, 24, 0xff000000, 0x00ff0000, 0x0000ff00,  0}, /* [31:0] R:G:B:x 8:8:8:8 little endian */
+    {VA_FOURCC_XBGR,   VA_LSB_FIRST,   32, 24, 0x000000ff, 0x0000ff00, 0x00ff0000,  0}, /* [31:0] x:B:G:R 8:8:8:8 little endian */
+    {VA_FOURCC_RGB565, VA_LSB_FIRST,   16, 16, 0xf800,     0x07e0,     0x001f,      0},
+    {VA_FOURCC_AYUV,   VA_LSB_FIRST,   32, 24, 0x00ff0000, 0x0000ff00, 0x000000ff,  0xff000000},
+    {VA_FOURCC_Y800,   VA_LSB_FIRST,   8,  0,0,0,0,0},
+    {VA_FOURCC_NV12,   VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_NV21,   VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_YUY2,   VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_UYVY,   VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_YV12,   VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_I420,   VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_411P,   VA_LSB_FIRST,   12, 0,0,0,0,0},
+    {VA_FOURCC_422H,   VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_422V,   VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_444P,   VA_LSB_FIRST,   24, 0,0,0,0,0},
+    {VA_FOURCC_IMC3,   VA_LSB_FIRST,   16, 0,0,0,0,0},
+    {VA_FOURCC_P010,   VA_LSB_FIRST,   24, 0,0,0,0,0},
+    {VA_FOURCC_Y210,   VA_LSB_FIRST,   32, 0,0,0,0,0},
+    {VA_FOURCC_Y410,   VA_LSB_FIRST,   32, 0,0,0,0,0},
+    {VA_FOURCC_A2R10G10B10,    VA_LSB_FIRST,   32, 30, 0x3ff00000, 0x000ffc00, 0x000003ff, 0x30000000},  /* [31:0] A:R:G:B 2:10:10:10 little endian */
+    {VA_FOURCC_A2B10G10R10,    VA_LSB_FIRST,   32, 30, 0x000003ff, 0x000ffc00, 0x3ff00000, 0x30000000}   /* [31:0] A:B:G:R 2:10:10:10 little endian */
 };
 
 const VAConfigAttribValEncRateControlExt MediaLibvaCapsG11::m_encVp9RateControlExt =
@@ -49,21 +73,20 @@ VAStatus MediaLibvaCapsG11::QueryImageFormats(VAImageFormat *formatList, int32_t
 {
     DDI_CHK_NULL(formatList, "Null pointer", VA_STATUS_ERROR_INVALID_PARAMETER);
     DDI_CHK_NULL(numFormats, "Null pointer", VA_STATUS_ERROR_INVALID_PARAMETER);
-    MediaLibvaCaps::QueryImageFormats(formatList, numFormats);
+    int32_t num = 0;
+    uint32_t maxNum = GetImageFormatsMaxNum();
 
-    int32_t num = *numFormats;
-    uint32_t numG11ImageFormats = GetNumG11ImageFormats();
-
-    for (int32_t idx = 0; idx < numG11ImageFormats; idx++)
+    memset(formatList, 0,  sizeof(m_supportedImageformatsG11));
+    for (uint32_t idx = 0; idx < maxNum; idx++)
     {
-        formatList[num].fourcc           = m_G11ImageFormats[idx].fourcc;
-        formatList[num].byte_order       = m_G11ImageFormats[idx].byte_order;
-        formatList[num].bits_per_pixel   = m_G11ImageFormats[idx].bits_per_pixel;
-        formatList[num].depth            = m_G11ImageFormats[idx].depth;
-        formatList[num].red_mask         = m_G11ImageFormats[idx].red_mask;
-        formatList[num].green_mask       = m_G11ImageFormats[idx].green_mask;
-        formatList[num].blue_mask        = m_G11ImageFormats[idx].blue_mask;
-        formatList[num].alpha_mask       = m_G11ImageFormats[idx].alpha_mask;
+        formatList[num].fourcc           = m_supportedImageformatsG11[idx].fourcc;
+        formatList[num].byte_order       = m_supportedImageformatsG11[idx].byte_order;
+        formatList[num].bits_per_pixel   = m_supportedImageformatsG11[idx].bits_per_pixel;
+        formatList[num].depth            = m_supportedImageformatsG11[idx].depth;
+        formatList[num].red_mask         = m_supportedImageformatsG11[idx].red_mask;
+        formatList[num].green_mask       = m_supportedImageformatsG11[idx].green_mask;
+        formatList[num].blue_mask        = m_supportedImageformatsG11[idx].blue_mask;
+        formatList[num].alpha_mask       = m_supportedImageformatsG11[idx].alpha_mask;
         num++;
     }
     *numFormats = num;
@@ -71,32 +94,39 @@ VAStatus MediaLibvaCapsG11::QueryImageFormats(VAImageFormat *formatList, int32_t
     return VA_STATUS_SUCCESS;
 }
 
-uint32_t MediaLibvaCapsG11::GetNumG11ImageFormats()
-{
-    return sizeof(m_G11ImageFormats)/sizeof(m_G11ImageFormats[0]);
-}
-
 uint32_t MediaLibvaCapsG11::GetImageFormatsMaxNum()
 {
-    return MediaLibvaCaps::GetImageFormatsMaxNum() +
-        GetNumG11ImageFormats();
+    return sizeof(m_supportedImageformatsG11)/sizeof(m_supportedImageformatsG11[0]);
+}
+
+bool MediaLibvaCapsG11::IsImageSupported(uint32_t fourcc)
+{
+    uint32_t maxNum = GetImageFormatsMaxNum();
+    for (int32_t idx = 0; idx < maxNum; idx++)
+    {
+        if (m_supportedImageformatsG11[idx].fourcc == fourcc)
+        {
+            return true;
+        }
+    }
+
+    return false;
 }
 
 VAStatus MediaLibvaCapsG11::PopulateColorMaskInfo(VAImageFormat *vaImgFmt)
 {
-    if(MediaLibvaCaps::PopulateColorMaskInfo(vaImgFmt) == VA_STATUS_SUCCESS)
-        return VA_STATUS_SUCCESS;
+    uint32_t maxNum = GetImageFormatsMaxNum();
 
-    uint32_t numG11ImageFormats = GetNumG11ImageFormats();
+    DDI_CHK_NULL(vaImgFmt, "Null pointer", VA_STATUS_ERROR_INVALID_PARAMETER);
 
-    for (int32_t idx = 0; idx < numG11ImageFormats; idx++)
+    for (int32_t idx = 0; idx < maxNum; idx++)
     {
-        if (m_G11ImageFormats[idx].fourcc == vaImgFmt->fourcc)
+        if (m_supportedImageformatsG11[idx].fourcc == vaImgFmt->fourcc)
         {
-            vaImgFmt->red_mask = m_G11ImageFormats[idx].red_mask;
-            vaImgFmt->green_mask = m_G11ImageFormats[idx].green_mask;
-            vaImgFmt->blue_mask = m_G11ImageFormats[idx].blue_mask;
-            vaImgFmt->alpha_mask = m_G11ImageFormats[idx].alpha_mask;
+            vaImgFmt->red_mask   = m_supportedImageformatsG11[idx].red_mask;
+            vaImgFmt->green_mask = m_supportedImageformatsG11[idx].green_mask;
+            vaImgFmt->blue_mask  = m_supportedImageformatsG11[idx].blue_mask;
+            vaImgFmt->alpha_mask = m_supportedImageformatsG11[idx].alpha_mask;
 
             return VA_STATUS_SUCCESS;
         }
@@ -132,6 +162,7 @@ CODECHAL_MODE MediaLibvaCapsG11::GetEncodeCodecMode(VAProfile profile, VAEntrypo
             return CODECHAL_ENCODE_MODE_VP9;
         case VAProfileHEVCMain:
         case VAProfileHEVCMain10:
+        case VAProfileHEVCMain422_10:
         case VAProfileHEVCMain444:
         case VAProfileHEVCMain444_10:
             return CODECHAL_ENCODE_MODE_HEVC;
@@ -180,14 +211,14 @@ std::string MediaLibvaCapsG11::GetDecodeCodecKey(VAProfile profile)
     }
 }
 
-std::string MediaLibvaCapsG11::GetEncodeCodecKey(VAProfile profile, VAEntrypoint entrypoint)
+std::string MediaLibvaCapsG11::GetEncodeCodecKey(VAProfile profile, VAEntrypoint entrypoint, uint32_t feiFunction)
 {
     switch (profile)
     {
         case VAProfileH264High:
         case VAProfileH264Main:
         case VAProfileH264ConstrainedBaseline:
-            if (IsEncFei(entrypoint))
+            if (IsEncFei(entrypoint, feiFunction))
             {
                 return ENCODE_ID_AVCFEI;
             }
@@ -209,9 +240,10 @@ std::string MediaLibvaCapsG11::GetEncodeCodecKey(VAProfile profile, VAEntrypoint
             return ENCODE_ID_VP9;
         case VAProfileHEVCMain:
         case VAProfileHEVCMain10:
+        case VAProfileHEVCMain422_10:
         case VAProfileHEVCMain444:
         case VAProfileHEVCMain444_10:
-            if (IsEncFei(entrypoint))
+            if (IsEncFei(entrypoint, feiFunction))
             {
                 return ENCODE_ID_HEVCFEI;
             }
@@ -220,7 +252,7 @@ std::string MediaLibvaCapsG11::GetEncodeCodecKey(VAProfile profile, VAEntrypoint
                 return ENCODE_ID_HEVC;
             }
         case VAProfileNone:
-            if (IsEncFei(entrypoint))
+            if (IsEncFei(entrypoint, feiFunction))
             {
                 return ENCODE_ID_AVCFEI;
             }
@@ -288,16 +320,19 @@ VAStatus MediaLibvaCapsG11::GetPlatformSpecificAttrib(VAProfile profile,
             }
             else if (IsAvcProfile(profile))
             {
-                // the capacity is differnt for CQP and BRC mode, set it as larger one here
-                uint32_t roiBRCPriorityLevelSupport = 1;
-                uint32_t roiBRCQpDeltaSupport = 1;
-                *value = (roiBRCPriorityLevelSupport << 9)
-                    | (roiBRCQpDeltaSupport << 8)
-                    | ENCODE_DP_AVC_MAX_ROI_NUM_BRC;
+                VAConfigAttribValEncROI roi_attrib = {0};
+                roi_attrib.bits.num_roi_regions = ENCODE_DP_AVC_MAX_ROI_NUM_BRC;
+                roi_attrib.bits.roi_rc_priority_support = 1;
+                roi_attrib.bits.roi_rc_qp_delta_support = 1;
+                *value = roi_attrib.value;
             }
-            else
+            else if (IsHevcProfile(profile))
             {
-                *value = 0;
+                VAConfigAttribValEncROI roi_attrib = {0};
+                roi_attrib.bits.num_roi_regions = CODECHAL_ENCODE_HEVC_MAX_NUM_ROI;
+                roi_attrib.bits.roi_rc_priority_support = 0;
+                roi_attrib.bits.roi_rc_qp_delta_support = 1;
+                *value = roi_attrib.value;
             }
             break;
         }
@@ -326,6 +361,43 @@ VAStatus MediaLibvaCapsG11::GetPlatformSpecificAttrib(VAProfile profile,
     return status;
 }
 
+VAStatus MediaLibvaCapsG11::LoadHevcEncProfileEntrypoints()
+{
+    VAStatus status = VA_STATUS_SUCCESS;
+
+#ifdef _HEVC_ENCODE_VME_SUPPORTED
+
+    status = MediaLibvaCaps::LoadHevcEncProfileEntrypoints();
+    DDI_CHK_RET(status, "Failed to initialize Caps!");
+
+    if (MEDIA_IS_SKU(&(m_mediaCtx->SkuTable), FtrEncodeHEVC))
+    {
+        SetAttribute(VAProfileHEVCMain, VAEntrypointEncSlice, VAConfigAttribEncTileSupport, 1);
+    }
+
+    if (MEDIA_IS_SKU(&(m_mediaCtx->SkuTable), FtrEncodeHEVC10bit))
+    {
+        SetAttribute(VAProfileHEVCMain10, VAEntrypointEncSlice, VAConfigAttribEncTileSupport, 1);
+    }
+
+    if (MEDIA_IS_SKU(&(m_mediaCtx->SkuTable), FtrEncodeHEVC12bit))
+    {
+        SetAttribute(VAProfileHEVCMain12, VAEntrypointEncSlice, VAConfigAttribEncTileSupport, 1);
+    }
+
+    if (MEDIA_IS_SKU(&(m_mediaCtx->SkuTable), FtrEncodeHEVC10bit422))
+    {
+        SetAttribute(VAProfileHEVCMain422_10, VAEntrypointEncSlice, VAConfigAttribEncTileSupport, 1);
+    }
+
+    if (MEDIA_IS_SKU(&(m_mediaCtx->SkuTable), FtrEncodeHEVC12bit422))
+    {
+        SetAttribute(VAProfileHEVCMain422_12, VAEntrypointEncSlice, VAConfigAttribEncTileSupport, 1);
+    }
+#endif
+    return status;
+}
+
 VAStatus MediaLibvaCapsG11::LoadHevcEncLpProfileEntrypoints()
 {
     VAStatus status = VA_STATUS_SUCCESS;
@@ -340,6 +412,7 @@ VAStatus MediaLibvaCapsG11::LoadHevcEncLpProfileEntrypoints()
     {
         status = CreateEncAttributes(VAProfileHEVCMain, VAEntrypointEncSliceLP, &attributeList);
         DDI_CHK_RET(status, "Failed to initialize Caps!");
+        (*attributeList)[VAConfigAttribEncTileSupport] = 1;
     }
 
     if (MEDIA_IS_SKU(&(m_mediaCtx->SkuTable), FtrEncodeHEVCVdencMain))
@@ -426,6 +499,7 @@ VAStatus MediaLibvaCapsG11::LoadVp9EncProfileEntrypoints()
         DDI_CHK_RET(status, "Failed to initialize Caps!");
         (*attributeList)[VAConfigAttribMaxPictureWidth] = m_maxVp9EncWidth;
         (*attributeList)[VAConfigAttribMaxPictureHeight] = m_maxVp9EncHeight;
+        (*attributeList)[VAConfigAttribEncDynamicScaling] = 1;
         (*attributeList)[VAConfigAttribEncTileSupport] = 1;
         (*attributeList)[VAConfigAttribEncRateControlExt] = m_encVp9RateControlExt.value;
     }
@@ -523,6 +597,7 @@ VAStatus MediaLibvaCapsG11::CheckEncodeResolution(
         uint32_t height)
 {
     uint32_t maxWidth, maxHeight;
+
     switch (profile)
     {
         case VAProfileJPEGBaseline:
@@ -536,6 +611,7 @@ VAStatus MediaLibvaCapsG11::CheckEncodeResolution(
             break;
         case VAProfileHEVCMain:
         case VAProfileHEVCMain10:
+        case VAProfileHEVCMain422_10:
         case VAProfileHEVCMain444:
         case VAProfileHEVCMain444_10:
             if (width > m_maxHevcEncWidth 
@@ -553,9 +629,7 @@ VAStatus MediaLibvaCapsG11::CheckEncodeResolution(
             if ((width > m_maxVp9EncWidth) ||
                 (width < m_encMinWidth) ||
                 (height > m_maxVp9EncHeight) ||
-                (height < m_encMinHeight) ||
-                (width % 8) ||
-                (height % 8))
+                (height < m_encMinHeight))
             {
                 return VA_STATUS_ERROR_RESOLUTION_NOT_SUPPORTED;
             }
@@ -668,6 +742,7 @@ GMM_RESOURCE_FORMAT MediaLibvaCapsG11::ConvertMediaFmtToGmmFmt(
         case Media_Format_R5G6B5     : return GMM_FORMAT_B5G6R5_UNORM_TYPE;
         case Media_Format_R8G8B8     : return GMM_FORMAT_R8G8B8_UNORM;
         case Media_Format_RGBP       : return GMM_FORMAT_RGBP;
+        case Media_Format_BGRP       : return GMM_FORMAT_BGRP;
         case Media_Format_NV12       : return GMM_FORMAT_NV12_TYPE;
         case Media_Format_NV21       : return GMM_FORMAT_NV21_TYPE;
         case Media_Format_YUY2       : return GMM_FORMAT_YUY2;
@@ -767,18 +842,10 @@ VAStatus MediaLibvaCapsG11::QuerySurfaceAttributes(
         attribs[i].type = VASurfaceAttribMemoryType;
         attribs[i].value.type = VAGenericValueTypeInteger;
         attribs[i].flags = VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE;
-#ifdef ANDROID
-        attribs[i].value.value.i = VA_SURFACE_ATTRIB_MEM_TYPE_VA |
-            VA_SURFACE_ATTRIB_MEM_TYPE_USER_PTR |
-            VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM |
-            VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME |
-            VA_SURFACE_ATTRIB_MEM_TYPE_ANDROID_GRALLOC;
-#else
         attribs[i].value.value.i = VA_SURFACE_ATTRIB_MEM_TYPE_VA |
             VA_SURFACE_ATTRIB_MEM_TYPE_USER_PTR |
             VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM |
             VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME;
-#endif
         i++;
 
         attribs[i].type = VASurfaceAttribExternalBufferDescriptor;
@@ -912,6 +979,11 @@ VAStatus MediaLibvaCapsG11::QuerySurfaceAttributes(
             maxWidth = m_decJpegMaxWidth;
             maxHeight = m_decJpegMaxHeight;
         }
+        else if(IsVp9Profile(profile))
+        {
+            maxWidth = m_decVp9MaxWidth;
+            maxHeight = m_decVp9MaxHeight;
+        }
 
         attribs[i].type = VASurfaceAttribMaxWidth;
         attribs[i].value.type = VAGenericValueTypeInteger;
@@ -924,6 +996,15 @@ VAStatus MediaLibvaCapsG11::QuerySurfaceAttributes(
         attribs[i].flags = VA_SURFACE_ATTRIB_GETTABLE;
         attribs[i].value.value.i = maxHeight;
         i++;
+
+        attribs[i].type = VASurfaceAttribMemoryType;
+        attribs[i].value.type = VAGenericValueTypeInteger;
+        attribs[i].flags = VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE;
+        attribs[i].value.value.i = VA_SURFACE_ATTRIB_MEM_TYPE_VA |
+            VA_SURFACE_ATTRIB_MEM_TYPE_USER_PTR |
+            VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM |
+            VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME;
+        i++;
     }
     else if(entrypoint == VAEntrypointEncSlice || entrypoint == VAEntrypointEncSliceLP || entrypoint == VAEntrypointEncPicture || entrypoint == VAEntrypointFEI)
     {
@@ -1062,6 +1143,15 @@ VAStatus MediaLibvaCapsG11::QuerySurfaceAttributes(
             attribs[i].value.value.i = m_encJpegMinHeight;
         }
         i++;
+
+        attribs[i].type = VASurfaceAttribMemoryType;
+        attribs[i].value.type = VAGenericValueTypeInteger;
+        attribs[i].flags = VA_SURFACE_ATTRIB_GETTABLE | VA_SURFACE_ATTRIB_SETTABLE;
+        attribs[i].value.value.i = VA_SURFACE_ATTRIB_MEM_TYPE_VA |
+            VA_SURFACE_ATTRIB_MEM_TYPE_USER_PTR |
+            VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM |
+            VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME;
+        i++;
     }
     else
     {
@@ -1083,9 +1173,43 @@ VAStatus MediaLibvaCapsG11::QuerySurfaceAttributes(
     return status;
 }
 
+VAStatus MediaLibvaCapsG11::CreateDecAttributes(
+        VAProfile profile,
+        VAEntrypoint entrypoint,
+        AttribMap **attributeList)
+{
+    VAStatus status = MediaLibvaCaps::CreateDecAttributes(profile, entrypoint, attributeList);
+    DDI_CHK_RET(status, "Failed to initialize Caps!");
+
+    auto attribList = *attributeList;
+    DDI_CHK_NULL(attribList, "Null pointer", VA_STATUS_ERROR_INVALID_PARAMETER);
+
+    VAConfigAttrib attrib;
+    attrib.type = VAConfigAttribRTFormat;
+    if(profile == VAProfileHEVCMain444)
+    {
+        attrib.value = VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV422 | VA_RT_FORMAT_YUV400 | VA_RT_FORMAT_YUV444;
+        (*attribList)[attrib.type] = attrib.value;
+    }
+    else if(profile == VAProfileHEVCMain444_10)
+    {
+        attrib.value = VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV422 | VA_RT_FORMAT_YUV400 | VA_RT_FORMAT_YUV444;
+        attrib.value |= VA_RT_FORMAT_YUV420_10 | VA_RT_FORMAT_YUV422_10 | VA_RT_FORMAT_YUV444_10;
+        (*attribList)[attrib.type] = attrib.value;
+    } else if(profile == VAProfileNone)
+    {
+        attrib.value = VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV422 | VA_RT_FORMAT_RGB32 | VA_RT_FORMAT_YUV444;
+        (*attribList)[attrib.type] = attrib.value;
+    }
+
+    return status;
+}
+
 extern template class MediaLibvaCapsFactory<MediaLibvaCaps, DDI_MEDIA_CONTEXT>;
 
 static bool iclRegistered = MediaLibvaCapsFactory<MediaLibvaCaps, DDI_MEDIA_CONTEXT>::
     RegisterCaps<MediaLibvaCapsG11>((uint32_t)IGFX_ICELAKE); 
 static bool icllpRegistered = MediaLibvaCapsFactory<MediaLibvaCaps, DDI_MEDIA_CONTEXT>::
     RegisterCaps<MediaLibvaCapsG11>((uint32_t)IGFX_ICELAKE_LP);
+static bool ehlRegistered = MediaLibvaCapsFactory<MediaLibvaCaps, DDI_MEDIA_CONTEXT>::
+    RegisterCaps<MediaLibvaCapsG11>((uint32_t)IGFX_ELKHARTLAKE);
